@@ -1,6 +1,7 @@
+
 /*
  * OLSR ad-hoc routing table management protocol GUI front-end
- * Copyright (C) 2003 Andreas Tnnesen (andreto@ifi.uio.no)
+ * Copyright (C) 2003 Andreas Tonnesen (andreto@ifi.uio.no)
  *
  * This file is part of olsr.org.
  *
@@ -21,7 +22,7 @@
  */
 
 /*
- *Andreas Tnnesen (andreto@ifi.uio.no)
+ *Andreas Tonnesen (andreto@ifi.uio.no)
  *
  *The list of cached packets
  *
@@ -43,62 +44,53 @@ add_packet_to_buffer(union olsr_message *p, int size)
   struct packnode *tmp;
   /* Should be the same for v4 and v6 */
 
-
   /* If this is the first packet */
-  if(!packets)
-    {
-      //printf("Adding first packet\n");
+  if (!packets) {
+    //printf("Adding first packet\n");
+    packets = malloc(sizeof(struct packnode));
+    packets->packet = malloc(size);
+    memcpy(packets->packet, p, size);
+    packets->next = NULL;
+    no_packets++;
+    return 1;
+  } else {
+    /* If the buffer is not full */
+    if (no_packets < MAXPACKS) {
+      //printf("Buffer not filled yet..\n");
+      tmp = packets;
       packets = malloc(sizeof(struct packnode));
       packets->packet = malloc(size);
       memcpy(packets->packet, p, size);
-      packets->next = NULL;
+      packets->next = tmp;
       no_packets++;
       return 1;
     }
-  else
-    {
-      /* If the buffer is not full */
-      if(no_packets < MAXPACKS)
-	{
-	  //printf("Buffer not filled yet..\n");
-	  tmp = packets;
-	  packets = malloc(sizeof(struct packnode));
-	  packets->packet = malloc(size);
-	  memcpy(packets->packet, p, size);
-	  packets->next = tmp;
-	  no_packets++;
-	  return 1;
-	}
-      /* If buffer is full */
-      else
-	{
-	  //printf("Buffer full - deleting...\n");
-	  tmp = packets;
-	  /* Find second last packet */
-	  while(tmp->next->next)
-	    {
-	      tmp = tmp->next;
-	    }
-	  /* Delete last packet */
-	  free(tmp->next->packet);
-	  free(tmp->next);
-	  tmp->next = NULL;
-
-	  /*Add the new packet */
-	  tmp = packets;
-	  packets = malloc(sizeof(struct packnode));
-	  packets->packet = malloc(size);
-	  memcpy(packets->packet, p, size);
-	  packets->next = tmp;
-	  return 1;
-	}
+    /* If buffer is full */
+    else {
+      //printf("Buffer full - deleting...\n");
+      tmp = packets;
+      /* Find second last packet */
+      while (tmp->next->next) {
+        tmp = tmp->next;
+      }
+      /* Delete last packet */
+      free(tmp->next->packet);
+      free(tmp->next);
+      tmp->next = NULL;
 
+      /*Add the new packet */
+      tmp = packets;
+      packets = malloc(sizeof(struct packnode));
+      packets->packet = malloc(size);
+      memcpy(packets->packet, p, size);
+      packets->next = tmp;
+      return 1;
     }
+
+  }
   return 0;
 }
 
-
-
 /*
  *Get the packet with index 'index'
  */
@@ -108,19 +100,25 @@ get_packet(int index)
   int i = 0;
   struct packnode *tmp;
 
-  if(index>MAXPACKS)
+  if (index > MAXPACKS)
     return 0;
 
-  if(index == 0)
+  if (index == 0)
     return packets->packet;
 
   tmp = packets;
 
-  while(i != index)
-    {
-      tmp = tmp->next;
-      i++;
-    }
+  while (i != index) {
+    tmp = tmp->next;
+    i++;
+  }
   return tmp->packet;
 
 }
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
