@@ -987,14 +987,14 @@ BMF_handle_listeningFd(int skfd, void *data, unsigned int flags __attribute__ ((
   } /* if (pktAddr.sll_pkttype ...) */
 
   /* Check if the received packet is UDP - BMF port */
-  ipHeader = (struct ip*)rxBuffer;
+  ipHeader = (struct ip*) ARM_NOWARN_ALIGN(rxBuffer);
   if (ipHeader->ip_p != SOL_UDP)
   {
     /* Not UDP */
     return;
   }
 
-  udpHeader = (struct udphdr*)(rxBuffer + GetIpHeaderLength(rxBuffer));
+  udpHeader = (struct udphdr*) ARM_NOWARN_ALIGN((rxBuffer + GetIpHeaderLength(rxBuffer)));
   destPort = ntohs(udpHeader->dest);
   if (destPort != BMF_ENCAP_PORT)
   {
