@@ -46,9 +46,9 @@
 #ifndef ADMIN_INTERFACE_H
 #define ADMIN_INTERFACE_H
 
-int build_admin_body(char *, olsr_u32_t);
+int build_admin_body(char *, uint32_t);
 
-int process_set_values(char *, olsr_u32_t, char *, olsr_u32_t);
+int process_set_values(char *, uint32_t, char *, uint32_t);
 
 int process_param(char *, char *);
 
