@@ -285,6 +285,7 @@ CreateInterface(const char *ifName, struct interface *olsrIntf)
    * added at the front of the list, non-OLSR interfaces at the back. */
   if (BmfInterfaces == NULL) {
     /* First TBmfInterface object in list */
+    newIf->next = NULL;
     BmfInterfaces = newIf;
     LastBmfInterface = newIf;
   } else if (olsrIntf != NULL) {
@@ -420,11 +421,11 @@ CreateBmfNetworkInterfaces(struct interface *skipThisIntf)
 void
 AddInterface(struct interface *newIntf)
 {
-  int nOpened;
+  /* int nOpened; */
 
   assert(newIntf != NULL);
 
-  nOpened = CreateInterface(newIntf->int_name, newIntf);
+  /* nOpened = */ (void)CreateInterface(newIntf->int_name, newIntf);
 
   //OLSR_PRINTF(1, "%s: opened %d sockets\n", PLUGIN_NAME, nOpened);
 }                               /* AddInterface */
