@@ -1,6 +1,6 @@
 #include "compat.h"
 
-#ifndef linux
+#if !defined(__linux__) && !defined(__GLIBC__)
 #include <stdlib.h>
 #include <string.h>
 
@@ -11,12 +11,12 @@ strndup(const char *ptr, size_t size)
   size_t len = strlen(ptr);
   char *ret = NULL;
 
-  if(len > size)
+  if (len > size)
     len = size;
 
   ret = malloc(len + 1);
-  
-  if(!ret)
+
+  if (!ret)
     return NULL;
 
   memcpy(ret, ptr, len);
@@ -26,3 +26,10 @@ strndup(const char *ptr, size_t size)
 }
 
 #endif
+
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
