@@ -123,8 +123,8 @@ PacketReceivedFromOLSR(unsigned char *encapsulationUdpData, int len)
   int destPort;
   bool isInList = false;
 
-  ipHeader = (struct ip *)encapsulationUdpData;
-  ip6Header = (struct ip6_hdr *)encapsulationUdpData;
+  ipHeader = (struct ip *) ARM_NOWARN_ALIGN(encapsulationUdpData);
+  ip6Header = (struct ip6_hdr *) ARM_NOWARN_ALIGN(encapsulationUdpData);
   //OLSR_DEBUG(LOG_PLUGINS, "P2PD PLUGIN got packet from OLSR message\n");
 
   if (check_and_mark_recent_packet(encapsulationUdpData, len))
@@ -196,8 +196,8 @@ PacketReceivedFromOLSR(unsigned char *encapsulationUdpData, int len)
       if (olsr_cnf->ip_version == AF_INET) {
         // Determine the IP address and the port from the header information
         if (ipHeader->ip_p == SOL_UDP && !IsIpv4Fragment(ipHeader)) {
-          udpHeader = (struct udphdr*)(encapsulationUdpData +
-                                       GetIpHeaderLength(encapsulationUdpData));
+          udpHeader = (struct udphdr*) ARM_NOWARN_ALIGN((encapsulationUdpData +
+                                       GetIpHeaderLength(encapsulationUdpData)));
           destAddr.v4.s_addr = ipHeader->ip_dst.s_addr;
           destPort = htons(udpHeader->dest);
           isInList = InUdpDestPortList(AF_INET, &destAddr, destPort);
@@ -216,7 +216,7 @@ PacketReceivedFromOLSR(unsigned char *encapsulationUdpData, int len)
         }
       } else /* (olsr_cnf->ip_version == AF_INET6) */ {
         if (ip6Header->ip6_nxt == SOL_UDP && !IsIpv6Fragment(ip6Header)) {
-          udpHeader = (struct udphdr*)(encapsulationUdpData + 40);
+          udpHeader = (struct udphdr*) ARM_NOWARN_ALIGN((encapsulationUdpData + 40));
           memcpy(&destAddr.v6, &ip6Header->ip6_dst, sizeof(struct in6_addr));
           destPort = htons(udpHeader->dest);
           isInList = InUdpDestPortList(AF_INET6, &destAddr, destPort);
@@ -409,18 +409,15 @@ olsr_parser(union olsr_message *m,
 {
   union olsr_ip_addr originator;
   int size;
-  uint32_t vtime;
 
   //OLSR_DEBUG(LOG_PLUGINS, "P2PD PLUGIN: Received msg in parser\n");
 
 	/* Fetch the originator of the messsage */
   if (olsr_cnf->ip_version == AF_INET) {
     memcpy(&originator, &m->v4.originator, olsr_cnf->ipsize);
-    vtime = me_to_reltime(m->v4.olsr_vtime);
     size = ntohs(m->v4.olsr_msgsize);
   } else {
     memcpy(&originator, &m->v6.originator, olsr_cnf->ipsize);
-    vtime = me_to_reltime(m->v6.olsr_vtime);
     size = ntohs(m->v6.olsr_msgsize);
   }
 
@@ -617,9 +614,7 @@ InUdpDestPortList(int ip_version, union olsr_ip_addr *addr, uint16_t port)
 static void
 P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
 {
-  union olsr_ip_addr src;      /* Source IP address in captured packet */
   union olsr_ip_addr dst;      /* Destination IP address in captured packet */
-  union olsr_ip_addr *origIp;  /* Main OLSR address of source of captured packet */
   struct ip *ipHeader;         /* The IP header inside the captured IP packet */
   struct ip6_hdr *ipHeader6;   /* The IP header inside the captured IP packet */
   struct udphdr *udpHeader;
@@ -627,7 +622,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
 
   if ((encapsulationUdpData[0] & 0xf0) == 0x40) {       //IPV4
 
-    ipHeader = (struct ip *)encapsulationUdpData;
+    ipHeader = (struct ip *) ARM_NOWARN_ALIGN(encapsulationUdpData);
 
     dst.v4 = ipHeader->ip_dst;
 
@@ -651,8 +646,8 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
     if (check_and_mark_recent_packet(encapsulationUdpData, nBytes))
       return;
 
-    udpHeader = (struct udphdr *)(encapsulationUdpData +
-                                  GetIpHeaderLength(encapsulationUdpData));
+    udpHeader = (struct udphdr *) ARM_NOWARN_ALIGN((encapsulationUdpData +
+                                  GetIpHeaderLength(encapsulationUdpData)));
     destPort = ntohs(udpHeader->dest);
 
     if (!InUdpDestPortList(AF_INET, &dst, destPort)) {
@@ -666,7 +661,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
   }                            //END IPV4
   else if ((encapsulationUdpData[0] & 0xf0) == 0x60) {  //IPv6
 
-    ipHeader6 = (struct ip6_hdr *)encapsulationUdpData;
+    ipHeader6 = (struct ip6_hdr *) ARM_NOWARN_ALIGN(encapsulationUdpData);
 
     memcpy(&dst.v6, &ipHeader6->ip6_dst, sizeof(struct in6_addr));
 
@@ -693,7 +688,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
     if (check_and_mark_recent_packet(encapsulationUdpData, nBytes))
       return;
 
-    udpHeader = (struct udphdr *)(encapsulationUdpData + 40);
+    udpHeader = (struct udphdr *) ARM_NOWARN_ALIGN((encapsulationUdpData + 40));
     destPort = ntohs(udpHeader->dest);
 
     if (!InUdpDestPortList(AF_INET6, &dst, destPort)) {
@@ -709,9 +704,6 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
     return;                     //Is not IP packet
   }
 
-  /* Lookup main address of source in the MID table of OLSR */
-  origIp = MainAddressOf(&src);
-
   // send the packet to OLSR forward mechanism
   olsr_p2pd_gen(encapsulationUdpData, nBytes);
 }                               /* P2pdPacketCaptured */
