@@ -46,7 +46,6 @@
 
 #include "olsrd_pgraph.h"
 #include "ipcalc.h"
-#include "socket_parser.h"
 #include "olsrd_plugin.h"
 #include "plugin_util.h"
 #include "net_olsr.h"
@@ -139,7 +138,7 @@ olsrd_get_plugin_parameters(const struct olsrd_plugin_parameters **params, int *
 /* Event function to register with the sceduler */
 static int pcf_event(int, int, int);
 
-static void ipc_action(int);
+static void ipc_action(int, void *, unsigned int);
 
 static void ipc_print_neigh_link(struct neighbor_entry *neighbor);
 
@@ -226,7 +225,7 @@ plugin_ipc_init(void)
       perror("SO_REUSEADDR failed");
       return 0;
     }
-#ifdef __FreeBSD__
+#if defined __FreeBSD__
     if (setsockopt(ipc_socket, SOL_SOCKET, SO_NOSIGPIPE, (char *)&yes, sizeof(yes)) < 0) {
       perror("SO_NOSIGPIPE failed");
       return 0;
@@ -254,14 +253,14 @@ plugin_ipc_init(void)
     }
 
     /* Register with olsrd */
-    add_olsr_socket(ipc_socket, &ipc_action);
+    add_olsr_socket(ipc_socket, &ipc_action, NULL, NULL, SP_PR_READ);
   }
 
   return 1;
 }
 
 static void
-ipc_action(int fd __attribute__ ((unused)))
+ipc_action(int fd __attribute__ ((unused)), void *data __attribute__ ((unused)), unsigned int flags __attribute__ ((unused)))
 {
   struct sockaddr_in pin;
   socklen_t addrlen;
@@ -301,7 +300,7 @@ ipc_action(int fd __attribute__ ((unused)))
  *Scheduled event
  */
 static int
-pcf_event(int changes_neighborhood, int changes_topology, int changes_hna __attribute__ ((unused)))
+pcf_event(int my_changes_neighborhood, int my_changes_topology, int my_changes_hna __attribute__ ((unused)))
 {
   int res;
   struct neighbor_entry *neighbor_table_tmp;
@@ -310,7 +309,7 @@ pcf_event(int changes_neighborhood, int changes_topology, int changes_hna __attr
 
   res = 0;
 
-  if (changes_neighborhood || changes_topology) {
+  if (my_changes_neighborhood || my_changes_topology) {
     /* Print tables to IPC socket */
 
     //ipc_send("start ", strlen("start "));
@@ -385,7 +384,7 @@ ipc_send(const char *data, int size)
   if (ipc_connection == -1)
     return 0;
 
-#if defined __FreeBSD__ || defined __MacOSX__ || __OpenBSD__
+#if defined __FreeBSD__ || defined __FreeBSD_kernel__ || defined __MacOSX__ || __OpenBSD__
 #define FLAG 0
 #else
 #define FLAG MSG_NOSIGNAL
