@@ -258,33 +258,33 @@ MD5Init(MD5_CTX * context)
 void
 MD5Update(MD5_CTX * context, const unsigned char *input, const unsigned int inputLen)
 {
-  unsigned int i, index, partLen;
+  unsigned int i, idx, partLen;
 
   /* Compute number of bytes mod 64 */
-  index = (unsigned int)((context->count[0] >> 3) & 0x3F);
+  idx = (unsigned int)((context->count[0] >> 3) & 0x3F);
 
   /* Update number of bits */
   if ((context->count[0] += ((UINT4) inputLen << 3)) < ((UINT4) inputLen << 3))
     context->count[1]++;
   context->count[1] += ((UINT4) inputLen >> 29);
 
-  partLen = 64 - index;
+  partLen = 64 - idx;
 
   /* Transform as many times as possible.
    */
   if (inputLen >= partLen) {
-    MD5_memcpy((POINTER) & context->buffer[index], input, partLen);
+    MD5_memcpy((POINTER) & context->buffer[idx], input, partLen);
     MD5Transform(context->state, context->buffer);
 
     for (i = partLen; i + 63 < inputLen; i += 64)
       MD5Transform(context->state, &input[i]);
 
-    index = 0;
+    idx = 0;
   } else
     i = 0;
 
   /* Buffer remaining input */
-  MD5_memcpy((POINTER) & context->buffer[index], &input[i], inputLen - i);
+  MD5_memcpy((POINTER) & context->buffer[idx], &input[i], inputLen - i);
 }
 
 /* MD5 finalization. Ends an MD5 message-digest operation, writing the
@@ -294,15 +294,15 @@ void
 MD5Final(unsigned char digest[16], MD5_CTX * context)
 {
   unsigned char bits[8];
-  unsigned int index, padLen;
+  unsigned int idx, padLen;
 
   /* Save number of bits */
   Encode(bits, context->count, 8);
 
   /* Pad out to 56 mod 64.
    */
-  index = (unsigned int)((context->count[0] >> 3) & 0x3f);
-  padLen = (index < 56) ? (56 - index) : (120 - index);
+  idx = (unsigned int)((context->count[0] >> 3) & 0x3f);
+  padLen = (idx < 56) ? (56 - idx) : (120 - idx);
   MD5Update(context, PADDING, padLen);
 
   /* Append length (before padding) */
