@@ -35,6 +35,12 @@
  *
  */
 
+/* Adjustments made to ensure data going out is converted to network
+ * byte ordering.  Also, to ensure incoming data is converted before
+ * it is used and before checksums are calculated as well.
+ * 06/06/2011 - Rusty Haddock AE5AE -- for the HSMM-MESH project.
+ */
+
 /*
  * Dynamic linked library for the olsr.org olsr daemon
  */
@@ -44,9 +50,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#ifdef linux
-#include <linux/in_route.h>
-#endif
 #include <unistd.h>
 #include <errno.h>
 #include <signal.h>
@@ -54,7 +57,6 @@
 #include "defs.h"
 #include "ipcalc.h"
 #include "olsr.h"
-#include "socket_parser.h"
 #include "parser.h"
 #include "scheduler.h"
 #include "net_olsr.h"
@@ -73,7 +75,7 @@
 #include "md5.h"
 
 static void
-MD5_checksum(const olsr_u8_t * data, const olsr_u16_t data_len, olsr_u8_t * hashbuf)
+MD5_checksum(const uint8_t * data, const uint16_t data_len, uint8_t * hashbuf)
 {
   MD5_CTX context;
 
@@ -100,7 +102,7 @@ MD5_checksum(const olsr_u8_t * data, const olsr_u16_t data_len, olsr_u8_t * hash
 #ifdef linux
 #define OS "GNU/Linux"
 #endif
-#ifdef __FreeBSD__
+#if defined __FreeBSD__ || defined __FreeBSD_kernel__
 #define OS "FreeBSD"
 #endif
 
@@ -115,10 +117,10 @@ struct stamp {
   union olsr_ip_addr addr;
   /* Timestamp difference */
   int diff;
-  olsr_u32_t challenge;
-  olsr_u8_t validated;
-  clock_t valtime;                     /* Validity time */
-  clock_t conftime;                    /* Reconfiguration time */
+  uint32_t challenge;
+  uint8_t validated;
+  uint32_t valtime;                     /* Validity time */
+  uint32_t conftime;                    /* Reconfiguration time */
   struct stamp *prev;
   struct stamp *next;
 };
@@ -139,8 +141,8 @@ char aes_key[16];
 static void olsr_event(void);
 #endif
 static int send_challenge(struct interface *olsr_if, const union olsr_ip_addr *);
-static int send_cres(struct interface *olsr_if, union olsr_ip_addr *, union olsr_ip_addr *, olsr_u32_t, struct stamp *);
-static int send_rres(struct interface *olsr_if, union olsr_ip_addr *, union olsr_ip_addr *, olsr_u32_t);
+static int send_cres(struct interface *olsr_if, union olsr_ip_addr *, union olsr_ip_addr *, uint32_t, struct stamp *);
+static int send_rres(struct interface *olsr_if, union olsr_ip_addr *, union olsr_ip_addr *, uint32_t);
 static int parse_challenge(struct interface *olsr_if, char *);
 static int parse_cres(struct interface *olsr_if, char *);
 static int parse_rres(char *);
@@ -148,7 +150,7 @@ static int check_auth(struct interface *olsr_if, char *, int *);
 #if 0
 static int ipc_send(char *, int);
 #endif
-static int add_signature(olsr_u8_t *, int *);
+static int add_signature(uint8_t *, int *);
 static int validate_packet(struct interface *olsr_if, const char *, int *);
 static char *secure_preprocessor(char *packet, struct interface *olsr_if, union olsr_ip_addr *from_addr, int *length);
 static void timeout_timestamps(void *);
@@ -304,19 +306,19 @@ check_auth(struct interface *olsr_if, char *pck, int *size __attribute__ ((unuse
  * increase the size
  */
 int
-add_signature(olsr_u8_t * pck, int *size)
+add_signature(uint8_t * pck, int *size)
 {
   struct s_olsrmsg *msg;
 #ifdef DEBUG
   unsigned int i;
   int j;
-  const olsr_u8_t *sigmsg;
+  const uint8_t *sigmsg;
 #endif
 
   olsr_printf(2, "[ENC]Adding signature for packet size %d\n", *size);
   fflush(stdout);
 
-  msg = (struct s_olsrmsg *)&pck[*size];
+  msg = (struct s_olsrmsg *)ARM_NOWARN_ALIGN(&pck[*size]);
   /* Update size */
   ((struct olsr *)pck)->olsr_packlen = htons(*size + sizeof(struct s_olsrmsg));
 
@@ -336,13 +338,14 @@ add_signature(olsr_u8_t * pck, int *size)
 
   /* Add timestamp */
   msg->sig.timestamp = htonl(now.tv_sec);
-  olsr_printf(3, "[ENC]timestamp: %ld\n", now.tv_sec);
-
+#ifndef WIN32
+  olsr_printf(3, "[ENC]timestamp: %lld\n", (long long)now.tv_sec);
+#endif
   /* Set the new size */
   *size += sizeof(struct s_olsrmsg);
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, pck, *size - SIGNATURE_SIZE);
@@ -357,7 +360,7 @@ add_signature(olsr_u8_t * pck, int *size)
   olsr_printf(1, "Signature message:\n");
 
   j = 0;
-  sigmsg = (olsr_u8_t *) msg;
+  sigmsg = (uint8_t *) msg;
 
   for (i = 0; i < sizeof(struct s_olsrmsg); i++) {
     olsr_printf(1, "  %3i", sigmsg[i]);
@@ -378,14 +381,14 @@ static int
 validate_packet(struct interface *olsr_if, const char *pck, int *size)
 {
   int packetsize;
-  olsr_u8_t sha1_hash[SIGNATURE_SIZE];
+  uint8_t sha1_hash[SIGNATURE_SIZE];
   const struct s_olsrmsg *sig;
   time_t rec_time;
 
 #ifdef DEBUG
   unsigned int i;
   int j;
-  const olsr_u8_t *sigmsg;
+  const uint8_t *sigmsg;
 #endif
 
   /* Find size - signature message */
@@ -394,7 +397,7 @@ validate_packet(struct interface *olsr_if, const char *pck, int *size)
   if (packetsize < 4)
     return 0;
 
-  sig = (const struct s_olsrmsg *)&pck[packetsize];
+  sig = (const struct s_olsrmsg *)CONST_ARM_NOWARN_ALIGN(&pck[packetsize]);
 
   //olsr_printf(1, "Size: %d\n", packetsize);
 
@@ -402,7 +405,7 @@ validate_packet(struct interface *olsr_if, const char *pck, int *size)
   olsr_printf(1, "Input message:\n");
 
   j = 0;
-  sigmsg = (const olsr_u8_t *)sig;
+  sigmsg = (const uint8_t *)sig;
 
   for (i = 0; i < sizeof(struct s_olsrmsg); i++) {
     olsr_printf(1, "  %3i", sigmsg[i]);
@@ -441,7 +444,7 @@ validate_packet(struct interface *olsr_if, const char *pck, int *size)
 one_checksum_SHA:
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, pck, *size - SIGNATURE_SIZE);
@@ -455,7 +458,7 @@ one_checksum_SHA:
 #ifdef DEBUG
   olsr_printf(1, "Recevied hash:\n");
 
-  sigmsg = (const olsr_u8_t *)sig->sig.signature;
+  sigmsg = (const uint8_t *)sig->sig.signature;
 
   for (i = 0; i < SIGNATURE_SIZE; i++) {
     olsr_printf(1, " %3i", sigmsg[i]);
@@ -486,9 +489,9 @@ one_checksum_SHA:
                 olsr_ip_to_string(&buf, (const union olsr_ip_addr *)&sig->originator));
     return 0;
   }
-
-  olsr_printf(1, "[ENC]Received timestamp %ld diff: %ld\n", rec_time, now.tv_sec - rec_time);
-
+#ifndef WIN32
+  olsr_printf(1, "[ENC]Received timestamp %lld diff: %lld\n", (long long)rec_time, (long long)now.tv_sec - (long long)rec_time);
+#endif
   /* Remove signature message */
   *size = packetsize;
   return 1;
@@ -549,7 +552,7 @@ send_challenge(struct interface *olsr_if, const union olsr_ip_addr *new_host)
 {
   struct challengemsg cmsg;
   struct stamp *entry;
-  olsr_u32_t challenge, hash;
+  uint32_t challenge, hash;
   struct ipaddr_str buf;
 
   olsr_printf(1, "[ENC]Building CHALLENGE message\n");
@@ -575,7 +578,7 @@ send_challenge(struct interface *olsr_if, const union olsr_ip_addr *new_host)
   olsr_printf(3, "[ENC]Size: %lu\n", (unsigned long)sizeof(struct challengemsg));
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, &cmsg, sizeof(struct challengemsg) - SIGNATURE_SIZE);
@@ -621,11 +624,11 @@ int
 parse_cres(struct interface *olsr_if, char *in_msg)
 {
   struct c_respmsg *msg;
-  olsr_u8_t sha1_hash[SIGNATURE_SIZE];
+  uint8_t sha1_hash[SIGNATURE_SIZE];
   struct stamp *entry;
   struct ipaddr_str buf;
 
-  msg = (struct c_respmsg *)in_msg;
+  msg = (struct c_respmsg *)ARM_NOWARN_ALIGN(in_msg);
 
   olsr_printf(1, "[ENC]Challenge-response message received\n");
   olsr_printf(3, "[ENC]To: %s\n", olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->destination));
@@ -640,7 +643,7 @@ parse_cres(struct interface *olsr_if, char *in_msg)
   /* Check signature */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, msg, sizeof(struct c_respmsg) - SIGNATURE_SIZE);
@@ -660,7 +663,6 @@ parse_cres(struct interface *olsr_if, char *in_msg)
 
   /* Now to check the digest from the emitted challenge */
   if ((entry = lookup_timestamp_entry((const union olsr_ip_addr *)&msg->originator)) == NULL) {
-    struct ipaddr_str buf;
     olsr_printf(1, "[ENC]Received challenge-response from non-registered node %s!\n",
                 olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->originator));
     return 0;
@@ -670,18 +672,22 @@ parse_cres(struct interface *olsr_if, char *in_msg)
   olsr_printf(3, "[ENC]Entry-challenge 0x%x\n", entry->challenge);
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
+    uint32_t netorder_challenge;
+
     /* First the challenge received */
-    memcpy(checksum_cache, &entry->challenge, 4);
+    /* But we have to calculate our hash with the challenge in
+     * network order just like the remote host did!  06/06/2011 AE5AE */
+    netorder_challenge = htonl(entry->challenge);
+    memcpy(checksum_cache, &netorder_challenge, sizeof(uint32_t));
     /* Then the local IP */
-    memcpy(&checksum_cache[sizeof(olsr_u32_t)], &msg->originator, olsr_cnf->ipsize);
+    memcpy(&checksum_cache[sizeof(uint32_t)], &msg->originator, olsr_cnf->ipsize);
 
     /* Create the hash */
-    CHECKSUM(checksum_cache, sizeof(olsr_u32_t) + olsr_cnf->ipsize, sha1_hash);
+    CHECKSUM(checksum_cache, sizeof(uint32_t) + olsr_cnf->ipsize, sha1_hash);
   }
 
   if (memcmp(msg->res_sig, sha1_hash, SIGNATURE_SIZE) != 0) {
-    struct ipaddr_str buf;
     olsr_printf(1, "[ENC]Error in challenge signature from %s!\n", olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->originator));
 
     return 0;
@@ -693,7 +699,9 @@ parse_cres(struct interface *olsr_if, char *in_msg)
 
   entry->challenge = 0;
   entry->validated = 1;
-  entry->diff = now.tv_sec - msg->timestamp;
+
+  /* Bring timestamp to host order before arith. 05/31/2011  AE5AE */
+  entry->diff = now.tv_sec - ntohl(msg->timestamp);
 
   /* update validtime - validated entry */
   entry->valtime = GET_TIMESTAMP(TIMESTAMP_HOLD_TIME * 1000);
@@ -702,7 +710,10 @@ parse_cres(struct interface *olsr_if, char *in_msg)
               entry->diff);
 
   /* Send response-response */
-  send_rres(olsr_if, (union olsr_ip_addr *)&msg->originator, (union olsr_ip_addr *)&msg->destination, ntohl(msg->challenge));
+  send_rres(olsr_if, (union olsr_ip_addr *)&msg->originator,
+	    (union olsr_ip_addr *)&msg->destination, msg->challenge);
+/* Don't give send_rres() the challenge in host order, the checksum needs to
+ * be calculated in network order.  06/06/2011  AE5AE */
 
   return 1;
 }
@@ -711,11 +722,11 @@ int
 parse_rres(char *in_msg)
 {
   struct r_respmsg *msg;
-  olsr_u8_t sha1_hash[SIGNATURE_SIZE];
+  uint8_t sha1_hash[SIGNATURE_SIZE];
   struct stamp *entry;
   struct ipaddr_str buf;
 
-  msg = (struct r_respmsg *)in_msg;
+  msg = (struct r_respmsg *)ARM_NOWARN_ALIGN(in_msg);
 
   olsr_printf(1, "[ENC]Response-response message received\n");
   olsr_printf(3, "[ENC]To: %s\n", olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->destination));
@@ -728,7 +739,7 @@ parse_rres(char *in_msg)
   /* Check signature */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, msg, sizeof(struct r_respmsg) - SIGNATURE_SIZE);
@@ -748,7 +759,6 @@ parse_rres(char *in_msg)
 
   /* Now to check the digest from the emitted challenge */
   if ((entry = lookup_timestamp_entry((const union olsr_ip_addr *)&msg->originator)) == NULL) {
-    struct ipaddr_str buf;
     olsr_printf(1, "[ENC]Received response-response from non-registered node %s!\n",
                 olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->originator));
     return 0;
@@ -758,18 +768,22 @@ parse_rres(char *in_msg)
   olsr_printf(3, "[ENC]Entry-challenge 0x%x\n", entry->challenge);
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
+    uint32_t netorder_challenge;
+
     /* First the challenge received */
-    memcpy(checksum_cache, &entry->challenge, 4);
+    /* But we have to calculate our hash with the challenge in network order! 06/06/2011  AE5AE */
+    netorder_challenge = htonl(entry->challenge);
+    memcpy(checksum_cache, &netorder_challenge, sizeof(uint32_t));
+
     /* Then the local IP */
-    memcpy(&checksum_cache[sizeof(olsr_u32_t)], &msg->originator, olsr_cnf->ipsize);
+    memcpy(&checksum_cache[sizeof(uint32_t)], &msg->originator, olsr_cnf->ipsize);
 
     /* Create the hash */
-    CHECKSUM(checksum_cache, sizeof(olsr_u32_t) + olsr_cnf->ipsize, sha1_hash);
+    CHECKSUM(checksum_cache, sizeof(uint32_t) + olsr_cnf->ipsize, sha1_hash);
   }
 
   if (memcmp(msg->res_sig, sha1_hash, SIGNATURE_SIZE) != 0) {
-    struct ipaddr_str buf;
     olsr_printf(1, "[ENC]Error in response signature from %s!\n", olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->originator));
 
     return 0;
@@ -781,7 +795,9 @@ parse_rres(char *in_msg)
 
   entry->challenge = 0;
   entry->validated = 1;
-  entry->diff = now.tv_sec - msg->timestamp;
+
+  /* Bring timestamp to host order before arith. 05/31/2011  AE5AE */
+  entry->diff = now.tv_sec - ntohl(msg->timestamp);
 
   /* update validtime - validated entry */
   entry->valtime = GET_TIMESTAMP(TIMESTAMP_HOLD_TIME * 1000);
@@ -796,12 +812,12 @@ int
 parse_challenge(struct interface *olsr_if, char *in_msg)
 {
   struct challengemsg *msg;
-  olsr_u8_t sha1_hash[SIGNATURE_SIZE];
+  uint8_t sha1_hash[SIGNATURE_SIZE];
   struct stamp *entry;
-  olsr_u32_t hash;
+  uint32_t hash;
   struct ipaddr_str buf;
 
-  msg = (struct challengemsg *)in_msg;
+  msg = (struct challengemsg *)ARM_NOWARN_ALIGN(in_msg);
 
   olsr_printf(1, "[ENC]Challenge message received\n");
   olsr_printf(3, "[ENC]To: %s\n", olsr_ip_to_string(&buf, (union olsr_ip_addr *)&msg->destination));
@@ -839,7 +855,7 @@ parse_challenge(struct interface *olsr_if, char *in_msg)
   /* Check signature */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, msg, sizeof(struct challengemsg) - SIGNATURE_SIZE);
@@ -864,7 +880,10 @@ parse_challenge(struct interface *olsr_if, char *in_msg)
 
   /* Build and send response */
 
-  send_cres(olsr_if, (union olsr_ip_addr *)&msg->originator, (union olsr_ip_addr *)&msg->destination, ntohl(msg->challenge), entry);
+  send_cres(olsr_if, (union olsr_ip_addr *)&msg->originator,
+	    (union olsr_ip_addr *)&msg->destination, msg->challenge, entry);
+/* Don't give send_cres() the challenge in host order, as the checksum needs to
+ * be calculated with network order.   06/06/2011  AE5AE */
 
   return 1;
 }
@@ -875,10 +894,10 @@ parse_challenge(struct interface *olsr_if, char *in_msg)
  *
  */
 int
-send_cres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr *from, olsr_u32_t chal_in, struct stamp *entry)
+send_cres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr *from, uint32_t chal_in, struct stamp *entry)
 {
   struct c_respmsg crmsg;
-  olsr_u32_t challenge;
+  uint32_t challenge;
   struct ipaddr_str buf;
 
   olsr_printf(1, "[ENC]Building CRESPONSE message\n");
@@ -900,8 +919,12 @@ send_cres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr
   crmsg.seqno = htons(get_msg_seqno());
 
   /* set timestamp */
-  crmsg.timestamp = now.tv_sec;
-  olsr_printf(3, "[ENC]Timestamp %ld\n", crmsg.timestamp);
+  /* but swap the byte order to the network order before sending!  05/28/2011  AE5AE */
+  crmsg.timestamp = htonl(now.tv_sec);
+#ifndef WIN32
+  /* Don't print htonl()'d time, use original now.tv_sec.  05/31/2011  AE5AE */
+  olsr_printf(3, "[ENC]Timestamp %lld\n", (long long)now.tv_sec);
+#endif
 
   /* Fill subheader */
   memcpy(&crmsg.destination, to, olsr_cnf->ipsize);
@@ -910,21 +933,21 @@ send_cres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr
   /* Create digest of received challenge + IP */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the challenge received */
     memcpy(checksum_cache, &chal_in, 4);
     /* Then the local IP */
-    memcpy(&checksum_cache[sizeof(olsr_u32_t)], from, olsr_cnf->ipsize);
+    memcpy(&checksum_cache[sizeof(uint32_t)], from, olsr_cnf->ipsize);
 
     /* Create the hash */
-    CHECKSUM(checksum_cache, sizeof(olsr_u32_t) + olsr_cnf->ipsize, crmsg.res_sig);
+    CHECKSUM(checksum_cache, sizeof(uint32_t) + olsr_cnf->ipsize, crmsg.res_sig);
   }
 
   /* Now create the digest of the message and the key */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, &crmsg, sizeof(struct c_respmsg) - SIGNATURE_SIZE);
@@ -951,7 +974,7 @@ send_cres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr
  *
  */
 static int
-send_rres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr *from, olsr_u32_t chal_in)
+send_rres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr *from, uint32_t chal_in)
 {
   struct r_respmsg rrmsg;
   struct ipaddr_str buf;
@@ -968,30 +991,34 @@ send_rres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr
   rrmsg.seqno = htons(get_msg_seqno());
 
   /* set timestamp */
-  rrmsg.timestamp = now.tv_sec;
-  olsr_printf(3, "[ENC]Timestamp %ld\n", rrmsg.timestamp);
+  /* But swap the byte order to the network order!  05/28/2011  AE5AE */
+  rrmsg.timestamp = htonl(now.tv_sec);
 
+#ifndef WIN32
+  /* don't print htonl()'d time, use original now.tv_sec.  05/31/2011  AE5AE */
+  olsr_printf(3, "[ENC]Timestamp %lld\n", (long long)now.tv_sec);
+#endif
   /* Fill subheader */
   memcpy(&rrmsg.destination, to, olsr_cnf->ipsize);
 
   /* Create digest of received challenge + IP */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the challenge received */
     memcpy(checksum_cache, &chal_in, 4);
     /* Then the local IP */
-    memcpy(&checksum_cache[sizeof(olsr_u32_t)], from, olsr_cnf->ipsize);
+    memcpy(&checksum_cache[sizeof(uint32_t)], from, olsr_cnf->ipsize);
 
     /* Create the hash */
-    CHECKSUM(checksum_cache, sizeof(olsr_u32_t) + olsr_cnf->ipsize, rrmsg.res_sig);
+    CHECKSUM(checksum_cache, sizeof(uint32_t) + olsr_cnf->ipsize, rrmsg.res_sig);
   }
 
   /* Now create the digest of the message and the key */
 
   {
-    olsr_u8_t checksum_cache[512 + KEYLENGTH];
+    uint8_t checksum_cache[512 + KEYLENGTH];
     /* Create packet + key cache */
     /* First the OLSR packet + signature message - digest */
     memcpy(checksum_cache, &rrmsg, sizeof(struct r_respmsg) - SIGNATURE_SIZE);
@@ -1016,7 +1043,7 @@ send_rres(struct interface *olsr_if, union olsr_ip_addr *to, union olsr_ip_addr
 static struct stamp *
 lookup_timestamp_entry(const union olsr_ip_addr *adr)
 {
-  olsr_u32_t hash;
+  uint32_t hash;
   struct stamp *entry;
   struct ipaddr_str buf;
 
@@ -1044,15 +1071,15 @@ timeout_timestamps(void *foo __attribute__ ((unused)))
 {
   struct stamp *tmp_list;
   struct stamp *entry_to_delete;
-  int index;
+  int idx;
 
   /* Update our local timestamp */
   gettimeofday(&now, NULL);
 
-  for (index = 0; index < HASHSIZE; index++) {
-    tmp_list = timestamps[index].next;
+  for (idx = 0; idx < HASHSIZE; idx++) {
+    tmp_list = timestamps[idx].next;
     /*Traverse MID list */
-    while (tmp_list != &timestamps[index]) {
+    while (tmp_list != &timestamps[idx]) {
       /*Check if the entry is timed out */
       if ((TIMED_OUT(tmp_list->valtime)) && (TIMED_OUT(tmp_list->conftime))) {
         struct ipaddr_str buf;
