@@ -1,10 +1,9 @@
+
 /*
-** $Id: liolib.c,v 1.2 2007/04/20 13:46:03 bernd67 Exp $
 ** Standard I/O (and system) library
 ** See Copyright Notice in lua.h
 */
 
-
 #include <errno.h>
 #include <locale.h>
 #include <stdio.h>
@@ -19,8 +18,6 @@
 #include "lauxlib.h"
 #include "lualib.h"
 
-
-
 /*
 ** by default, gcc does not get `tmpname'
 */
@@ -32,7 +29,6 @@
 #endif
 #endif
 
-
 /*
 ** by default, posix systems get `popen'
 */
@@ -48,10 +44,7 @@
 #define USE_POPEN	0
 #endif
 
-
-
-static int io_exit (lua_State *L) __attribute__((noreturn));
-
+static int io_exit(lua_State * L) __attribute__ ((noreturn));
 
 /*
 ** {======================================================
@@ -59,24 +52,22 @@ static int io_exit (lua_State *L) __attribute__((noreturn));
 ** =======================================================
 */
 
-
 #if !USE_POPEN
 #define pclose(f)    (-1)
 #endif
 
-
 #define FILEHANDLE		"FILE*"
 
 #define IO_INPUT		"_input"
 #define IO_OUTPUT		"_output"
 
-
-static int pushresult (lua_State *L, int i, const char *filename) {
+static int
+pushresult(lua_State * L, int i, const char *filename)
+{
   if (i) {
     lua_pushboolean(L, 1);
     return 1;
-  }
-  else {
+  } else {
     lua_pushnil(L);
     if (filename)
       lua_pushfstring(L, "%s: %s", filename, strerror(errno));
@@ -87,17 +78,21 @@ static int pushresult (lua_State *L, int i, const char *filename) {
   }
 }
 
-
-static FILE **topfile (lua_State *L, int findex) {
-  FILE **f = (FILE **)luaL_checkudata(L, findex, FILEHANDLE);
-  if (f == NULL) luaL_argerror(L, findex, "bad file");
+static FILE **
+topfile(lua_State * L, int findex)
+{
+  FILE **f = (FILE **) luaL_checkudata(L, findex, FILEHANDLE);
+  if (f == NULL)
+    luaL_argerror(L, findex, "bad file");
   return f;
 }
 
-
-static int io_type (lua_State *L) {
-  FILE **f = (FILE **)luaL_checkudata(L, 1, FILEHANDLE);
-  if (f == NULL) lua_pushnil(L);
+static int
+io_type(lua_State * L)
+{
+  FILE **f = (FILE **) luaL_checkudata(L, 1, FILEHANDLE);
+  if (f == NULL)
+    lua_pushnil(L);
   else if (*f == NULL)
     lua_pushliteral(L, "closed file");
   else
@@ -105,61 +100,64 @@ static int io_type (lua_State *L) {
   return 1;
 }
 
-
-static FILE *tofile (lua_State *L, int findex) {
+static FILE *
+tofile(lua_State * L, int findex)
+{
   FILE **f = topfile(L, findex);
   if (*f == NULL)
     luaL_error(L, "attempt to use a closed file");
   return *f;
 }
 
-
-
 /*
 ** When creating file handles, always creates a `closed' file handle
 ** before opening the actual file; so, if there is a memory error, the
 ** file is not left opened.
 */
-static FILE **newfile (lua_State *L) {
-  FILE **pf = (FILE **)lua_newuserdata(L, sizeof(FILE *));
-  *pf = NULL;  /* file handle is currently `closed' */
+static FILE **
+newfile(lua_State * L)
+{
+  FILE **pf = (FILE **) lua_newuserdata(L, sizeof(FILE *));
+  *pf = NULL;                   /* file handle is currently `closed' */
   luaL_getmetatable(L, FILEHANDLE);
   lua_setmetatable(L, -2);
   return pf;
 }
 
-
 /*
 ** assumes that top of the stack is the `io' library, and next is
 ** the `io' metatable
 */
-static void registerfile (lua_State *L, FILE *f, const char *name,
-                                                 const char *impname) {
+static void
+registerfile(lua_State * L, FILE * f, const char *name, const char *impname)
+{
   lua_pushstring(L, name);
   *newfile(L) = f;
   if (impname) {
     lua_pushstring(L, impname);
     lua_pushvalue(L, -2);
-    lua_settable(L, -6);  /* metatable[impname] = file */
+    lua_settable(L, -6);        /* metatable[impname] = file */
   }
-  lua_settable(L, -3);  /* io[name] = file */
+  lua_settable(L, -3);          /* io[name] = file */
 }
 
-
-static int aux_close (lua_State *L) {
+static int
+aux_close(lua_State * L)
+{
   FILE *f = tofile(L, 1);
   if (f == stdin || f == stdout || f == stderr)
-    return 0;  /* file cannot be closed */
+    return 0;                   /* file cannot be closed */
   else {
     int ok = (pclose(f) != -1) || (fclose(f) == 0);
     if (ok)
-      *(FILE **)lua_touserdata(L, 1) = NULL;  /* mark file as closed */
+      *(FILE **) lua_touserdata(L, 1) = NULL;   /* mark file as closed */
     return ok;
   }
 }
 
-
-static int io_close (lua_State *L) {
+static int
+io_close(lua_State * L)
+{
   if (lua_isnone(L, 1) && lua_type(L, lua_upvalueindex(1)) == LUA_TTABLE) {
     lua_pushstring(L, IO_OUTPUT);
     lua_rawget(L, lua_upvalueindex(1));
@@ -167,16 +165,18 @@ static int io_close (lua_State *L) {
   return pushresult(L, aux_close(L), NULL);
 }
 
-
-static int io_gc (lua_State *L) {
+static int
+io_gc(lua_State * L)
+{
   FILE **f = topfile(L, 1);
-  if (*f != NULL)  /* ignore closed files */
+  if (*f != NULL)               /* ignore closed files */
     aux_close(L);
   return 0;
 }
 
-
-static int io_tostring (lua_State *L) {
+static int
+io_tostring(lua_State * L)
+{
   char buff[128];
   FILE **f = topfile(L, 1);
   if (*f == NULL)
@@ -187,8 +187,9 @@ static int io_tostring (lua_State *L) {
   return 1;
 }
 
-
-static int io_open (lua_State *L) {
+static int
+io_open(lua_State * L)
+{
   const char *filename = luaL_checkstring(L, 1);
   const char *mode = luaL_optstring(L, 2, "r");
   FILE **pf = newfile(L);
@@ -196,8 +197,9 @@ static int io_open (lua_State *L) {
   return (*pf == NULL) ? pushresult(L, 0, filename) : 1;
 }
 
-
-static int io_popen (lua_State *L) {
+static int
+io_popen(lua_State * L)
+{
 #if !USE_POPEN
   luaL_error(L, "`popen' not supported");
   return 0;
@@ -210,22 +212,25 @@ static int io_popen (lua_State *L) {
 #endif
 }
 
-
-static int io_tmpfile (lua_State *L) {
+static int
+io_tmpfile(lua_State * L)
+{
   FILE **pf = newfile(L);
   *pf = tmpfile();
   return (*pf == NULL) ? pushresult(L, 0, NULL) : 1;
 }
 
-
-static FILE *getiofile (lua_State *L, const char *name) {
+static FILE *
+getiofile(lua_State * L, const char *name)
+{
   lua_pushstring(L, name);
   lua_rawget(L, lua_upvalueindex(1));
   return tofile(L, -1);
 }
 
-
-static int g_iofile (lua_State *L, const char *name, const char *mode) {
+static int
+g_iofile(lua_State * L, const char *name, const char *mode)
+{
   if (!lua_isnoneornil(L, 1)) {
     const char *filename = lua_tostring(L, 1);
     lua_pushstring(L, name);
@@ -236,9 +241,8 @@ static int g_iofile (lua_State *L, const char *name, const char *mode) {
         lua_pushfstring(L, "%s: %s", filename, strerror(errno));
         luaL_argerror(L, 1, lua_tostring(L, -1));
       }
-    }
-    else {
-      tofile(L, 1);  /* check that it's a valid file handle */
+    } else {
+      tofile(L, 1);             /* check that it's a valid file handle */
       lua_pushvalue(L, 1);
     }
     lua_rawset(L, lua_upvalueindex(1));
@@ -249,184 +253,195 @@ static int g_iofile (lua_State *L, const char *name, const char *mode) {
   return 1;
 }
 
-
-static int io_input (lua_State *L) {
+static int
+io_input(lua_State * L)
+{
   return g_iofile(L, IO_INPUT, "r");
 }
 
-
-static int io_output (lua_State *L) {
+static int
+io_output(lua_State * L)
+{
   return g_iofile(L, IO_OUTPUT, "w");
 }
 
+static int io_readline(lua_State * L);
 
-static int io_readline (lua_State *L);
-
-
-static void aux_lines (lua_State *L, int idx, int close) {
+static void
+aux_lines(lua_State * L, int idx, int close)
+{
   lua_pushliteral(L, FILEHANDLE);
   lua_rawget(L, LUA_REGISTRYINDEX);
   lua_pushvalue(L, idx);
-  lua_pushboolean(L, close);  /* close/not close file when finished */
+  lua_pushboolean(L, close);    /* close/not close file when finished */
   lua_pushcclosure(L, io_readline, 3);
 }
 
-
-static int f_lines (lua_State *L) {
-  tofile(L, 1);  /* check that it's a valid file handle */
+static int
+f_lines(lua_State * L)
+{
+  tofile(L, 1);                 /* check that it's a valid file handle */
   aux_lines(L, 1, 0);
   return 1;
 }
 
-
-static int io_lines (lua_State *L) {
+static int
+io_lines(lua_State * L)
+{
   if (lua_isnoneornil(L, 1)) {  /* no arguments? */
     lua_pushstring(L, IO_INPUT);
-    lua_rawget(L, lua_upvalueindex(1));  /* will iterate over default input */
+    lua_rawget(L, lua_upvalueindex(1)); /* will iterate over default input */
     return f_lines(L);
-  }
-  else {
+  } else {
     const char *filename = luaL_checkstring(L, 1);
     FILE **pf = newfile(L);
     *pf = fopen(filename, "r");
-    luaL_argcheck(L, *pf, 1,  strerror(errno));
+    luaL_argcheck(L, *pf, 1, strerror(errno));
     aux_lines(L, lua_gettop(L), 1);
     return 1;
   }
 }
 
-
 /*
 ** {======================================================
 ** READ
 ** =======================================================
 */
 
-
-static int read_number (lua_State *L, FILE *f) {
+static int
+read_number(lua_State * L, FILE * f)
+{
   lua_Number d;
   if (fscanf(f, LUA_NUMBER_SCAN, &d) == 1) {
     lua_pushnumber(L, d);
     return 1;
-  }
-  else return 0;  /* read fails */
+  } else
+    return 0;                   /* read fails */
 }
 
-
-static int test_eof (lua_State *L, FILE *f) {
+static int
+test_eof(lua_State * L, FILE * f)
+{
   int c = getc(f);
   ungetc(c, f);
   lua_pushlstring(L, NULL, 0);
   return (c != EOF);
 }
 
-
-static int read_line (lua_State *L, FILE *f) {
+static int
+read_line(lua_State * L, FILE * f)
+{
   luaL_Buffer b;
   luaL_buffinit(L, &b);
   for (;;) {
     size_t l;
     char *p = luaL_prepbuffer(&b);
-    if (fgets(p, LUAL_BUFFERSIZE, f) == NULL) {  /* eof? */
-      luaL_pushresult(&b);  /* close buffer */
-      return (lua_strlen(L, -1) > 0);  /* check whether read something */
+    if (fgets(p, LUAL_BUFFERSIZE, f) == NULL) { /* eof? */
+      luaL_pushresult(&b);      /* close buffer */
+      return (lua_strlen(L, -1) > 0);   /* check whether read something */
     }
     l = strlen(p);
-    if (p[l-1] != '\n')
+    if (p[l - 1] != '\n')
       luaL_addsize(&b, l);
     else {
       luaL_addsize(&b, l - 1);  /* do not include `eol' */
-      luaL_pushresult(&b);  /* close buffer */
-      return 1;  /* read at least an `eol' */
+      luaL_pushresult(&b);      /* close buffer */
+      return 1;                 /* read at least an `eol' */
     }
   }
 }
 
-
-static int read_chars (lua_State *L, FILE *f, size_t n) {
-  size_t rlen;  /* how much to read */
-  size_t nr;  /* number of chars actually read */
+static int
+read_chars(lua_State * L, FILE * f, size_t n)
+{
+  size_t rlen;                         /* how much to read */
+  size_t nr;                           /* number of chars actually read */
   luaL_Buffer b;
   luaL_buffinit(L, &b);
-  rlen = LUAL_BUFFERSIZE;  /* try to read that much each time */
+  rlen = LUAL_BUFFERSIZE;       /* try to read that much each time */
   do {
     char *p = luaL_prepbuffer(&b);
-    if (rlen > n) rlen = n;  /* cannot read more than asked */
+    if (rlen > n)
+      rlen = n;                 /* cannot read more than asked */
     nr = fread(p, sizeof(char), rlen, f);
     luaL_addsize(&b, nr);
-    n -= nr;  /* still have to read `n' chars */
-  } while (n > 0 && nr == rlen);  /* until end of count or eof */
-  luaL_pushresult(&b);  /* close buffer */
+    n -= nr;                    /* still have to read `n' chars */
+  }
+  while (n > 0 && nr == rlen);  /* until end of count or eof */
+  luaL_pushresult(&b);          /* close buffer */
   return (n == 0 || lua_strlen(L, -1) > 0);
 }
 
-
-static int g_read (lua_State *L, FILE *f, int first) {
+static int
+g_read(lua_State * L, FILE * f, int first)
+{
   int nargs = lua_gettop(L) - 1;
   int success;
   int n;
-  if (nargs == 0) {  /* no arguments? */
+  if (nargs == 0) {             /* no arguments? */
     success = read_line(L, f);
-    n = first+1;  /* to return 1 result */
-  }
-  else {  /* ensure stack space for all results and for auxlib's buffer */
-    luaL_checkstack(L, nargs+LUA_MINSTACK, "too many arguments");
+    n = first + 1;              /* to return 1 result */
+  } else {                      /* ensure stack space for all results and for auxlib's buffer */
+    luaL_checkstack(L, nargs + LUA_MINSTACK, "too many arguments");
     success = 1;
     for (n = first; nargs-- && success; n++) {
       if (lua_type(L, n) == LUA_TNUMBER) {
-        size_t l = (size_t)lua_tonumber(L, n);
+        size_t l = lua_tonumber(L, n);
         success = (l == 0) ? test_eof(L, f) : read_chars(L, f, l);
-      }
-      else {
+      } else {
         const char *p = lua_tostring(L, n);
         luaL_argcheck(L, p && p[0] == '*', n, "invalid option");
         switch (p[1]) {
-          case 'n':  /* number */
-            success = read_number(L, f);
-            break;
-          case 'l':  /* line */
-            success = read_line(L, f);
-            break;
-          case 'a':  /* file */
-            read_chars(L, f, ~((size_t)0));  /* read MAX_SIZE_T chars */
-            success = 1; /* always success */
-            break;
-          case 'w':  /* word */
-            return luaL_error(L, "obsolete option `*w' to `read'");
-          default:
-            return luaL_argerror(L, n, "invalid format");
+        case 'n':              /* number */
+          success = read_number(L, f);
+          break;
+        case 'l':              /* line */
+          success = read_line(L, f);
+          break;
+        case 'a':              /* file */
+          read_chars(L, f, ~((size_t) 0));      /* read MAX_SIZE_T chars */
+          success = 1;          /* always success */
+          break;
+        case 'w':              /* word */
+          return luaL_error(L, "obsolete option `*w' to `read'");
+        default:
+          return luaL_argerror(L, n, "invalid format");
         }
       }
     }
   }
   if (!success) {
-    lua_pop(L, 1);  /* remove last result */
-    lua_pushnil(L);  /* push nil instead */
+    lua_pop(L, 1);              /* remove last result */
+    lua_pushnil(L);             /* push nil instead */
   }
   return n - first;
 }
 
-
-static int io_read (lua_State *L) {
+static int
+io_read(lua_State * L)
+{
   return g_read(L, getiofile(L, IO_INPUT), 1);
 }
 
-
-static int f_read (lua_State *L) {
+static int
+f_read(lua_State * L)
+{
   return g_read(L, tofile(L, 1), 2);
 }
 
-
-static int io_readline (lua_State *L) {
-  FILE *f = *(FILE **)lua_touserdata(L, lua_upvalueindex(2));
-  if (f == NULL)  /* file is already closed? */
+static int
+io_readline(lua_State * L)
+{
+  FILE *f = *(FILE **) lua_touserdata(L, lua_upvalueindex(2));
+  if (f == NULL)                /* file is already closed? */
     luaL_error(L, "file is already closed");
-  if (read_line(L, f)) return 1;
-  else {  /* EOF */
-    if (lua_toboolean(L, lua_upvalueindex(3))) {  /* generator created file? */
+  if (read_line(L, f))
+    return 1;
+  else {                        /* EOF */
+    if (lua_toboolean(L, lua_upvalueindex(3))) {        /* generator created file? */
       lua_settop(L, 0);
       lua_pushvalue(L, lua_upvalueindex(2));
-      aux_close(L);  /* close it */
+      aux_close(L);             /* close it */
     }
     return 0;
   }
@@ -434,17 +449,16 @@ static int io_readline (lua_State *L) {
 
 /* }====================================================== */
 
-
-static int g_write (lua_State *L, FILE *f, int arg) {
+static int
+g_write(lua_State * L, FILE * f, int arg)
+{
   int nargs = lua_gettop(L) - 1;
   int status = 1;
   for (; nargs--; arg++) {
     if (lua_type(L, arg) == LUA_TNUMBER) {
       /* optimization: could be done exactly as for strings */
-      status = status &&
-          fprintf(f, LUA_NUMBER_FMT, lua_tonumber(L, arg)) > 0;
-    }
-    else {
+      status = status && fprintf(f, LUA_NUMBER_FMT, lua_tonumber(L, arg)) > 0;
+    } else {
       size_t l;
       const char *s = luaL_checklstring(L, arg, &l);
       status = status && (fwrite(s, sizeof(char), l, f) == l);
@@ -453,44 +467,48 @@ static int g_write (lua_State *L, FILE *f, int arg) {
   return pushresult(L, status, NULL);
 }
 
-
-static int io_write (lua_State *L) {
+static int
+io_write(lua_State * L)
+{
   return g_write(L, getiofile(L, IO_OUTPUT), 1);
 }
 
-
-static int f_write (lua_State *L) {
+static int
+f_write(lua_State * L)
+{
   return g_write(L, tofile(L, 1), 2);
 }
 
-
-static int f_seek (lua_State *L) {
-  static const int mode[] = {SEEK_SET, SEEK_CUR, SEEK_END};
-  static const char *const modenames[] = {"set", "cur", "end", NULL};
+static int
+f_seek(lua_State * L)
+{
+  static const int mode[] = { SEEK_SET, SEEK_CUR, SEEK_END };
+  static const char *const modenames[] = { "set", "cur", "end", NULL };
   FILE *f = tofile(L, 1);
   int op = luaL_findstring(luaL_optstring(L, 2, "cur"), modenames);
   long offset = luaL_optlong(L, 3, 0);
   luaL_argcheck(L, op != -1, 2, "invalid mode");
   op = fseek(f, offset, mode[op]);
   if (op)
-    return pushresult(L, 0, NULL);  /* error */
+    return pushresult(L, 0, NULL);      /* error */
   else {
     lua_pushnumber(L, ftell(f));
     return 1;
   }
 }
 
-
-static int io_flush (lua_State *L) {
+static int
+io_flush(lua_State * L)
+{
   return pushresult(L, fflush(getiofile(L, IO_OUTPUT)) == 0, NULL);
 }
 
-
-static int f_flush (lua_State *L) {
+static int
+f_flush(lua_State * L)
+{
   return pushresult(L, fflush(tofile(L, 1)) == 0, NULL);
 }
 
-
 static const luaL_reg iolib[] = {
   {"input", io_input},
   {"output", io_output},
@@ -506,7 +524,6 @@ static const luaL_reg iolib[] = {
   {NULL, NULL}
 };
 
-
 static const luaL_reg flib[] = {
   {"flush", f_flush},
   {"read", f_read},
@@ -519,51 +536,56 @@ static const luaL_reg flib[] = {
   {NULL, NULL}
 };
 
-
-static void createmeta (lua_State *L) {
-  luaL_newmetatable(L, FILEHANDLE);  /* create new metatable for file handles */
+static void
+createmeta(lua_State * L)
+{
+  luaL_newmetatable(L, FILEHANDLE);     /* create new metatable for file handles */
   /* file methods */
   lua_pushliteral(L, "__index");
-  lua_pushvalue(L, -2);  /* push metatable */
-  lua_rawset(L, -3);  /* metatable.__index = metatable */
+  lua_pushvalue(L, -2);         /* push metatable */
+  lua_rawset(L, -3);            /* metatable.__index = metatable */
   luaL_openlib(L, NULL, flib, 0);
 }
 
 /* }====================================================== */
 
-
 /*
 ** {======================================================
 ** Other O.S. Operations
 ** =======================================================
 */
 
-static int io_execute (lua_State *L) {
+static int
+io_execute(lua_State * L)
+{
   lua_pushnumber(L, system(luaL_checkstring(L, 1)));
   return 1;
 }
 
-
-static int io_remove (lua_State *L) {
+static int
+io_remove(lua_State * L)
+{
   const char *filename = luaL_checkstring(L, 1);
   return pushresult(L, remove(filename) == 0, filename);
 }
 
-
-static int io_rename (lua_State *L) {
+static int
+io_rename(lua_State * L)
+{
   const char *fromname = luaL_checkstring(L, 1);
   const char *toname = luaL_checkstring(L, 2);
   return pushresult(L, rename(fromname, toname) == 0, fromname);
 }
 
-
 #if !USE_TMPNAME
-static int io_tmpname (lua_State *L) __attribute__((noreturn));
+static int io_tmpname(lua_State * L) __attribute__ ((noreturn));
 #else
-static int io_tmpname (lua_State *L);
+static int io_tmpname(lua_State * L);
 #endif
 
-static int io_tmpname (lua_State *L) {
+static int
+io_tmpname(lua_State * L)
+{
 #if !USE_TMPNAME
   luaL_error(L, "`tmpname' not supported");
 #else
@@ -575,19 +597,20 @@ static int io_tmpname (lua_State *L) {
 #endif
 }
 
-
-static int io_getenv (lua_State *L) {
-  lua_pushstring(L, getenv(luaL_checkstring(L, 1)));  /* if NULL push nil */
+static int
+io_getenv(lua_State * L)
+{
+  lua_pushstring(L, getenv(luaL_checkstring(L, 1)));    /* if NULL push nil */
   return 1;
 }
 
-
-static int io_clock (lua_State *L) {
-  lua_pushnumber(L, ((lua_Number)clock())/(lua_Number)CLOCKS_PER_SEC);
+static int
+io_clock(lua_State * L)
+{
+  lua_pushnumber(L, clock() / (lua_Number) CLOCKS_PER_SEC);
   return 1;
 }
 
-
 /*
 ** {======================================================
 ** Time/Date operations
@@ -596,19 +619,25 @@ static int io_clock (lua_State *L) {
 ** =======================================================
 */
 
-static void setfield (lua_State *L, const char *key, int value) {
+static void
+setfield(lua_State * L, const char *key, int value)
+{
   lua_pushstring(L, key);
   lua_pushnumber(L, value);
   lua_rawset(L, -3);
 }
 
-static void setboolfield (lua_State *L, const char *key, int value) {
+static void
+setboolfield(lua_State * L, const char *key, int value)
+{
   lua_pushstring(L, key);
   lua_pushboolean(L, value);
   lua_rawset(L, -3);
 }
 
-static int getboolfield (lua_State *L, const char *key) {
+static int
+getboolfield(lua_State * L, const char *key)
+{
   int res;
   lua_pushstring(L, key);
   lua_gettable(L, -2);
@@ -617,13 +646,14 @@ static int getboolfield (lua_State *L, const char *key) {
   return res;
 }
 
-
-static int getfield (lua_State *L, const char *key, int d) {
+static int
+getfield(lua_State * L, const char *key, int d)
+{
   int res;
   lua_pushstring(L, key);
   lua_gettable(L, -2);
   if (lua_isnumber(L, -1))
-    res = (int)(lua_tonumber(L, -1));
+    res = lua_tonumber(L, -1);
   else {
     if (d == -2)
       return luaL_error(L, "field `%s' missing in date table", key);
@@ -633,20 +663,20 @@ static int getfield (lua_State *L, const char *key, int d) {
   return res;
 }
 
-
-static int io_date (lua_State *L) {
+static int
+io_date(lua_State * L)
+{
   const char *s = luaL_optstring(L, 1, "%c");
-  time_t t = (time_t)(luaL_optnumber(L, 2, -1));
+  time_t t = luaL_optnumber(L, 2, -1);
   struct tm *stm;
-  if (t == (time_t)(-1))  /* no time given? */
-    t = time(NULL);  /* use current time */
-  if (*s == '!') {  /* UTC? */
+  if (t == (time_t) (-1))       /* no time given? */
+    t = time(NULL);             /* use current time */
+  if (*s == '!') {              /* UTC? */
     stm = gmtime(&t);
-    s++;  /* skip `!' */
-  }
-  else
+    s++;                        /* skip `!' */
+  } else
     stm = localtime(&t);
-  if (stm == NULL)  /* invalid date? */
+  if (stm == NULL)              /* invalid date? */
     lua_pushnil(L);
   else if (strcmp(s, "*t") == 0) {
     lua_newtable(L);
@@ -654,13 +684,12 @@ static int io_date (lua_State *L) {
     setfield(L, "min", stm->tm_min);
     setfield(L, "hour", stm->tm_hour);
     setfield(L, "day", stm->tm_mday);
-    setfield(L, "month", stm->tm_mon+1);
-    setfield(L, "year", stm->tm_year+1900);
-    setfield(L, "wday", stm->tm_wday+1);
-    setfield(L, "yday", stm->tm_yday+1);
+    setfield(L, "month", stm->tm_mon + 1);
+    setfield(L, "year", stm->tm_year + 1900);
+    setfield(L, "wday", stm->tm_wday + 1);
+    setfield(L, "yday", stm->tm_yday + 1);
     setboolfield(L, "isdst", stm->tm_isdst);
-  }
-  else {
+  } else {
     char b[256];
     if (strftime(b, sizeof(b), s, stm))
       lua_pushstring(L, b);
@@ -670,15 +699,16 @@ static int io_date (lua_State *L) {
   return 1;
 }
 
-
-static int io_time (lua_State *L) {
-  if (lua_isnoneornil(L, 1))  /* called without args? */
-    lua_pushnumber(L, time(NULL));  /* return current time */
+static int
+io_time(lua_State * L)
+{
+  if (lua_isnoneornil(L, 1))    /* called without args? */
+    lua_pushnumber(L, time(NULL));      /* return current time */
   else {
     time_t t;
     struct tm ts;
     luaL_checktype(L, 1, LUA_TTABLE);
-    lua_settop(L, 1);  /* make sure table is at the top */
+    lua_settop(L, 1);           /* make sure table is at the top */
     ts.tm_sec = getfield(L, "sec", 0);
     ts.tm_min = getfield(L, "min", 0);
     ts.tm_hour = getfield(L, "hour", 12);
@@ -687,7 +717,7 @@ static int io_time (lua_State *L) {
     ts.tm_year = getfield(L, "year", -2) - 1900;
     ts.tm_isdst = getboolfield(L, "isdst");
     t = mktime(&ts);
-    if (t == (time_t)(-1))
+    if (t == (time_t) (-1))
       lua_pushnil(L);
     else
       lua_pushnumber(L, t);
@@ -695,21 +725,24 @@ static int io_time (lua_State *L) {
   return 1;
 }
 
-
-static int io_difftime (lua_State *L) {
-  lua_pushnumber(L, difftime((time_t)(luaL_checknumber(L, 1)),
-                             (time_t)(luaL_optnumber(L, 2, 0))));
+static int
+io_difftime(lua_State * L)
+{
+  lua_pushnumber(L, difftime(luaL_checknumber(L, 1), luaL_optnumber(L, 2, 0)));
   return 1;
 }
 
 /* }====================================================== */
 
-
-static int io_setloc (lua_State *L) {
-  static const int cat[] = {LC_ALL, LC_COLLATE, LC_CTYPE, LC_MONETARY,
-                      LC_NUMERIC, LC_TIME};
-  static const char *const catnames[] = {"all", "collate", "ctype", "monetary",
-     "numeric", "time", NULL};
+static int
+io_setloc(lua_State * L)
+{
+  static const int cat[] = { LC_ALL, LC_COLLATE, LC_CTYPE, LC_MONETARY,
+    LC_NUMERIC, LC_TIME
+  };
+  static const char *const catnames[] = { "all", "collate", "ctype", "monetary",
+    "numeric", "time", NULL
+  };
   const char *l = lua_tostring(L, 1);
   int op = luaL_findstring(luaL_optstring(L, 2, "all"), catnames);
   luaL_argcheck(L, l || lua_isnoneornil(L, 1), 1, "string expected");
@@ -718,31 +751,32 @@ static int io_setloc (lua_State *L) {
   return 1;
 }
 
-
-static int io_exit (lua_State *L) {
+static int
+io_exit(lua_State * L)
+{
   exit(luaL_optint(L, 1, EXIT_SUCCESS));
 }
 
 static const luaL_reg syslib[] = {
-  {"clock",     io_clock},
-  {"date",      io_date},
-  {"difftime",  io_difftime},
-  {"execute",   io_execute},
-  {"exit",      io_exit},
-  {"getenv",    io_getenv},
-  {"remove",    io_remove},
-  {"rename",    io_rename},
+  {"clock", io_clock},
+  {"date", io_date},
+  {"difftime", io_difftime},
+  {"execute", io_execute},
+  {"exit", io_exit},
+  {"getenv", io_getenv},
+  {"remove", io_remove},
+  {"rename", io_rename},
   {"setlocale", io_setloc},
-  {"time",      io_time},
-  {"tmpname",   io_tmpname},
+  {"time", io_time},
+  {"tmpname", io_tmpname},
   {NULL, NULL}
 };
 
 /* }====================================================== */
 
-
-
-LUALIB_API int luaopen_io (lua_State *L) {
+LUALIB_API int
+luaopen_io(lua_State * L)
+{
   luaL_openlib(L, LUA_OSLIBNAME, syslib, 0);
   createmeta(L);
   lua_pushvalue(L, -1);
@@ -754,3 +788,9 @@ LUALIB_API int luaopen_io (lua_State *L) {
   return 1;
 }
 
+/*
+ * Local Variables:
+ * c-basic-offset: 2
+ * indent-tabs-mode: nil
+ * End:
+ */
