@@ -45,6 +45,7 @@
 #include "log.h"
 #include "mantissa.h"
 #include "net_olsr.h"
+#include "gateway.h"
 
 #define BMSG_DBGLVL 5
 
@@ -67,7 +68,7 @@ static void check_buffspace(int msgsize, int buffsize, const char *type);
 static uint32_t msg_buffer_align[(MAXMESSAGESIZE - OLSR_HEADERSIZE)/sizeof(uint32_t) + 1];
 static uint8_t *msg_buffer = (uint8_t *)msg_buffer_align;
 
-static clock_t send_empty_tc;          /* TC empty message sending */
+static uint32_t send_empty_tc;          /* TC empty message sending */
 
 /* Prototypes for internal functions */
 
@@ -96,7 +97,7 @@ static bool serialize_hna6(struct interface *);
  * empty TC messages
  */
 void
-set_empty_tc_timer(clock_t empty_tc_new)
+set_empty_tc_timer(uint32_t empty_tc_new)
 {
   send_empty_tc = empty_tc_new;
 }
@@ -105,7 +106,7 @@ set_empty_tc_timer(clock_t empty_tc_new)
  * Get the timer that controls the generation of
  * empty TC messages
  */
-clock_t
+uint32_t
 get_empty_tc_timer(void)
 {
   return send_empty_tc;
@@ -250,7 +251,7 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
   union olsr_message *m;
   struct hellomsg *h;
   struct hellinfo *hinfo;
-  union olsr_ip_addr *haddr;
+  char *haddr;
   int i, j;
   bool first_entry;
 
@@ -273,7 +274,7 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
 
   h = &m->v4.message.hello;
   hinfo = h->hell_info;
-  haddr = (union olsr_ip_addr *)hinfo->neigh_addr;
+  haddr = (char *)hinfo->neigh_addr;
 
   /* Fill message header */
   m->v4.ttl = message->ttl;
@@ -292,10 +293,10 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
 
   /*
    *Loops trough all possible neighbor statuses
-   *The negbor list is grouped by status
+   *The neighbor list is grouped by status
    *
    */
-  /* Nighbor statuses */
+  /* Neighbor statuses */
   for (i = 0; i <= MAX_NEIGH; i++) {
     /* Link statuses */
     for (j = 0; j <= MAX_LINK; j++) {
@@ -315,6 +316,7 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
         if ((nb->status != i) || (nb->link != j))
           continue;
 
+
 #ifdef DEBUG
         OLSR_PRINTF(BMSG_DBGLVL, "\t%s - ", olsr_ip_to_string(&buf, &nb->address));
         OLSR_PRINTF(BMSG_DBGLVL, "L:%d N:%d\n", j, i);
@@ -349,7 +351,7 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
 
             h = &m->v4.message.hello;
             hinfo = h->hell_info;
-            haddr = (union olsr_ip_addr *)hinfo->neigh_addr;
+            haddr = (char *)hinfo->neigh_addr;
             /* Make sure typeheader is added */
             first_entry = true;
           }
@@ -369,10 +371,10 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
           curr_size += 4;       /* HELLO type section header */
         }
 
-        *haddr = nb->address;
+        memcpy(haddr, &nb->address, sizeof(union olsr_ip_addr));
 
         /* Point to next address */
-        haddr = (union olsr_ip_addr *)&haddr->v6.s6_addr[4];
+        haddr += olsr_cnf->ipsize;
         curr_size += olsr_cnf->ipsize;  /* IP address added */
 
         first_entry = false;
@@ -380,8 +382,10 @@ serialize_hello4(struct hello_message *message, struct interface *ifp)
 
       if (!first_entry) {
         hinfo->size = htons((char *)haddr - (char *)hinfo);
+
         hinfo = (struct hellinfo *)((char *)haddr);
-        haddr = (union olsr_ip_addr *)&hinfo->neigh_addr;
+        haddr = (char *)hinfo->neigh_addr;
+
       }
     }                           /* for j */
   }                             /* for i */
@@ -785,13 +789,13 @@ serialize_tc6(struct tc_message *message, struct interface *ifp)
 static bool
 serialize_mid4(struct interface *ifp)
 {
-  uint16_t remainsize, curr_size;
+  uint16_t remainsize, curr_size, needsize;
   /* preserve existing data in output buffer */
   union olsr_message *m;
   struct midaddr *addrs;
   struct interface *ifs;
 
-  if ((olsr_cnf->ip_version != AF_INET) || (!ifp) || (ifnet == NULL || ifnet->int_next == NULL))
+  if ((olsr_cnf->ip_version != AF_INET) || (!ifp) || (ifnet == NULL) || ((ifnet->int_next == NULL) && (ipequal(&olsr_cnf->main_addr, &ifnet->ip_addr))))
     return false;
 
   remainsize = net_outbuffer_bytes_left(ifp);
@@ -800,8 +804,14 @@ serialize_mid4(struct interface *ifp)
 
   curr_size = OLSR_MID_IPV4_HDRSIZE;
 
+  /* calculate size needed for HNA */
+  needsize = curr_size;
+  for (ifs = ifnet; ifs != NULL; ifs = ifs->int_next) {
+    needsize += olsr_cnf->ipsize*2;
+  }
+
   /* Send pending packet if not room in buffer */
-  if (curr_size > remainsize) {
+  if (needsize > remainsize) {
     net_output(ifp);
     remainsize = net_outbuffer_bytes_left(ifp);
   }
@@ -873,7 +883,7 @@ serialize_mid4(struct interface *ifp)
 static bool
 serialize_mid6(struct interface *ifp)
 {
-  uint16_t remainsize, curr_size;
+  uint16_t remainsize, curr_size, needsize;
   /* preserve existing data in output buffer */
   union olsr_message *m;
   struct midaddr6 *addrs6;
@@ -881,15 +891,21 @@ serialize_mid6(struct interface *ifp)
 
   //printf("\t\tGenerating mid on %s\n", ifn->int_name);
 
-  if ((olsr_cnf->ip_version != AF_INET6) || (!ifp) || (ifnet == NULL || ifnet->int_next == NULL))
+  if ((olsr_cnf->ip_version != AF_INET6) || (!ifp) || (ifnet == NULL) || ((ifnet->int_next == NULL) && (ipequal(&olsr_cnf->main_addr, &ifnet->ip_addr))))
     return false;
 
   remainsize = net_outbuffer_bytes_left(ifp);
 
   curr_size = OLSR_MID_IPV6_HDRSIZE;
 
+  /* calculate size needed for HNA */
+  needsize = curr_size;
+  for (ifs = ifnet; ifs != NULL; ifs = ifs->int_next) {
+    needsize += olsr_cnf->ipsize*2;
+  }
+
   /* Send pending packet if not room in buffer */
-  if (curr_size > remainsize) {
+  if (needsize > remainsize) {
     net_output(ifp);
     remainsize = net_outbuffer_bytes_left(ifp);
   }
@@ -960,7 +976,7 @@ serialize_mid6(struct interface *ifp)
 static bool
 serialize_hna4(struct interface *ifp)
 {
-  uint16_t remainsize, curr_size;
+  uint16_t remainsize, curr_size, needsize;
   /* preserve existing data in output buffer */
   union olsr_message *m;
   struct hnapair *pair;
@@ -982,8 +998,17 @@ serialize_hna4(struct interface *ifp)
 
   curr_size = OLSR_HNA_IPV4_HDRSIZE;
 
+  /* calculate size needed for HNA */
+  needsize = curr_size;
+  while (h) {
+    needsize += olsr_cnf->ipsize*2;
+    h = h->next;
+  }
+
+  h = olsr_cnf->hna_entries;
+
   /* Send pending packet if not room in buffer */
-  if (curr_size > remainsize) {
+  if (needsize > remainsize) {
     net_output(ifp);
     remainsize = net_outbuffer_bytes_left(ifp);
   }
@@ -1021,8 +1046,15 @@ serialize_hna4(struct interface *ifp)
 #ifdef DEBUG
     OLSR_PRINTF(BMSG_DBGLVL, "\tNet: %s\n", olsr_ip_prefix_to_string(&h->net));
 #endif
-    pair->addr = h->net.prefix.v4.s_addr;
+
     olsr_prefix_to_netmask(&ip_addr, h->net.prefix_len);
+#ifdef LINUX_NETLINK_ROUTING
+    if (olsr_cnf->smart_gw_active && is_prefix_inetgw(&h->net)) {
+      /* this is the default route, overwrite it with the smart gateway */
+      olsr_modifiy_inetgw_netmask(&ip_addr, h->net.prefix_len);
+    }
+#endif
+    pair->addr = h->net.prefix.v4.s_addr;
     pair->netmask = ip_addr.v4.s_addr;
     pair++;
     curr_size += (2 * olsr_cnf->ipsize);
@@ -1046,7 +1078,7 @@ serialize_hna4(struct interface *ifp)
 static bool
 serialize_hna6(struct interface *ifp)
 {
-  uint16_t remainsize, curr_size;
+  uint16_t remainsize, curr_size, needsize;
   /* preserve existing data in output buffer */
   union olsr_message *m;
   struct hnapair6 *pair6;
@@ -1061,8 +1093,17 @@ serialize_hna6(struct interface *ifp)
 
   curr_size = OLSR_HNA_IPV6_HDRSIZE;
 
+  /* calculate size needed for HNA */
+  needsize = curr_size;
+  while (h) {
+    needsize += olsr_cnf->ipsize*2;
+    h = h->next;
+  }
+
+  h = olsr_cnf->hna_entries;
+
   /* Send pending packet if not room in buffer */
-  if (curr_size > remainsize) {
+  if (needsize > remainsize) {
     net_output(ifp);
     remainsize = net_outbuffer_bytes_left(ifp);
   }
@@ -1099,8 +1140,14 @@ serialize_hna6(struct interface *ifp)
 #ifdef DEBUG
     OLSR_PRINTF(BMSG_DBGLVL, "\tNet: %s\n", olsr_ip_prefix_to_string(&h->net));
 #endif
-    pair6->addr = h->net.prefix.v6;
     olsr_prefix_to_netmask(&tmp_netmask, h->net.prefix_len);
+#ifdef LINUX_NETLINK_ROUTING
+    if (olsr_cnf->smart_gw_active && is_prefix_inetgw(&h->net)) {
+      /* this is the default gateway, so overwrite it with the smart one */
+      olsr_modifiy_inetgw_netmask(&tmp_netmask, h->net.prefix_len);
+    }
+#endif
+    pair6->addr = h->net.prefix.v6;
     pair6->netmask = tmp_netmask.v6;
     pair6++;
     curr_size += (2 * olsr_cnf->ipsize);
