@@ -136,7 +136,7 @@ typedef unsigned long ufpm;
 
 #else /* NDEBUG */
 
-fpm itofpm(int i);
+fpm itofpm(sfpm i);
 fpm ftofpm(float f);
 int fpmtoi(fpm a);
 float fpmtof(fpm a);
@@ -164,7 +164,6 @@ fpm fpmldiv(fpm a, fpm b);
 
 fpm atofpm(const char *);
 const char *fpmtoa(fpm);
-const char *etxtoa(fpm);
 
 #else /* USE_FPM */
 
@@ -176,7 +175,6 @@ const char *etxtoa(fpm);
 
 float atofpm(const char *);
 const char *fpmtoa(float);
-const char *etxtoa(float);
 
 #endif /* USE_FPM */
 
