@@ -45,12 +45,17 @@
 #include "scheduler.h"
 #include "net_olsr.h"
 #include "tc_set.h"
+#include "parser.h"
+#include "gateway.h"
+#include "duplicate_handler.h"
 
 struct hna_entry hna_set[HASHSIZE];
 struct olsr_cookie_info *hna_net_timer_cookie = NULL;
 struct olsr_cookie_info *hna_entry_mem_cookie = NULL;
 struct olsr_cookie_info *hna_net_mem_cookie = NULL;
 
+static bool olsr_delete_hna_net_entry(struct hna_net *net_to_delete);
+
 /**
  * Initialize the HNA set
  */
@@ -75,6 +80,17 @@ olsr_init_hna_set(void)
   return 1;
 }
 
+void
+olsr_cleanup_hna(union olsr_ip_addr *orig) {
+  struct hna_entry *hna;
+
+  OLSR_FOR_ALL_HNA_ENTRIES(hna) {
+    if (hna->networks.next != &hna->networks && ipequal(&hna->A_gateway_addr, orig)) {
+      while (!olsr_delete_hna_net_entry(hna->networks.next));
+    }
+  } OLSR_FOR_ALL_HNA_ENTRIES_END(hna)
+}
+
 /**
  * Lookup a network entry in a networkentry list.
  *
@@ -85,13 +101,13 @@ olsr_init_hna_set(void)
  * @return the localized entry or NULL of not found
  */
 struct hna_net *
-olsr_lookup_hna_net(const struct hna_net *nets, const union olsr_ip_addr *net, olsr_u8_t prefixlen)
+olsr_lookup_hna_net(const struct hna_net *nets, const union olsr_ip_addr *net, uint8_t prefixlen)
 {
   struct hna_net *tmp;
 
   /* Loop trough entrys */
   for (tmp = nets->next; tmp != nets; tmp = tmp->next) {
-    if (tmp->prefixlen == prefixlen && ipequal(&tmp->A_network_addr, net)) {
+    if (tmp->hna_prefix.prefix_len == prefixlen && ipequal(&tmp->hna_prefix.prefix, net)) {
       return tmp;
     }
   }
@@ -110,7 +126,7 @@ struct hna_entry *
 olsr_lookup_hna_gw(const union olsr_ip_addr *gw)
 {
   struct hna_entry *tmp_hna;
-  olsr_u32_t hash = olsr_ip_hashing(gw);
+  uint32_t hash = olsr_ip_hashing(gw);
 
 #if 0
   OLSR_PRINTF(5, "HNA: lookup entry\n");
@@ -138,7 +154,7 @@ struct hna_entry *
 olsr_add_hna_entry(const union olsr_ip_addr *addr)
 {
   struct hna_entry *new_entry;
-  olsr_u32_t hash;
+  uint32_t hash;
 
   new_entry = olsr_cookie_malloc(hna_entry_mem_cookie);
 
@@ -170,15 +186,15 @@ olsr_add_hna_entry(const union olsr_ip_addr *addr)
  * @return the newly created entry
  */
 struct hna_net *
-olsr_add_hna_net(struct hna_entry *hna_gw, const union olsr_ip_addr *net, olsr_u8_t prefixlen)
+olsr_add_hna_net(struct hna_entry *hna_gw, const union olsr_ip_addr *net, uint8_t prefixlen)
 {
   /* Add the net */
   struct hna_net *new_net = olsr_cookie_malloc(hna_net_mem_cookie);
 
   /* Fill struct */
   memset(new_net, 0, sizeof(struct hna_net));
-  new_net->A_network_addr = *net;
-  new_net->prefixlen = prefixlen;
+  new_net->hna_prefix.prefix = *net;
+  new_net->hna_prefix.prefix_len= prefixlen;
 
   /* Set backpointer */
   new_net->hna_gw = hna_gw;
@@ -192,40 +208,57 @@ olsr_add_hna_net(struct hna_entry *hna_gw, const union olsr_ip_addr *net, olsr_u
   return new_net;
 }
 
+static bool
+olsr_delete_hna_net_entry(struct hna_net *net_to_delete) {
+#ifdef DEBUG
+  struct ipaddr_str buf1, buf2;
+#endif
+  struct hna_entry *hna_gw;
+  bool removed_entry = false;
+
+#ifdef LINUX_NETLINK_ROUTING
+  if (is_prefix_inetgw(&net_to_delete->hna_prefix)) {
+    /* modify smart gateway entry if necessary */
+    olsr_delete_gateway_entry(&net_to_delete->hna_gw->A_gateway_addr, net_to_delete->hna_prefix.prefix_len);
+  }
+#endif
+
+  olsr_stop_timer(net_to_delete->hna_net_timer);
+  net_to_delete->hna_net_timer = NULL;  /* be pedandic */
+  hna_gw = net_to_delete->hna_gw;
+
+#ifdef DEBUG
+  OLSR_PRINTF(5, "HNA: timeout %s via hna-gw %s\n",
+      olsr_ip_prefix_to_string(&net_to_delete->hna_prefix),
+              olsr_ip_to_string(&buf2, &hna_gw->A_gateway_addr));
+#endif
+
+  /*
+   * Delete the rt_path for the entry.
+   */
+  olsr_delete_routing_table(&net_to_delete->hna_prefix.prefix,
+      net_to_delete->hna_prefix.prefix_len, &hna_gw->A_gateway_addr);
+
+  DEQUEUE_ELEM(net_to_delete);
+
+  /* Delete hna_gw if empty */
+  if (hna_gw->networks.next == &hna_gw->networks) {
+    DEQUEUE_ELEM(hna_gw);
+    olsr_cookie_free(hna_entry_mem_cookie, hna_gw);
+    removed_entry = true;
+  }
+
+  olsr_cookie_free(hna_net_mem_cookie, net_to_delete);
+  return removed_entry;
+}
+
 /**
  * Callback for the hna_net timer.
  */
 static void
 olsr_expire_hna_net_entry(void *context)
 {
-#ifdef DEBUG
-  struct ipaddr_str buf1, buf2;
-#endif
-  struct hna_net *net_to_delete;
-  struct hna_entry *hna_gw;
-
-  net_to_delete = (struct hna_net *)context;
-  net_to_delete->hna_net_timer = NULL;  /* be pedandic */
-  hna_gw = net_to_delete->hna_gw;
-
-#ifdef DEBUG
-  OLSR_PRINTF(5, "HNA: timeout %s/%u via hna-gw %s\n", olsr_ip_to_string(&buf1, &net_to_delete->A_network_addr),
-              net_to_delete->prefixlen, olsr_ip_to_string(&buf2, &hna_gw->A_gateway_addr));
-#endif
-
-  /*
-   * Delete the rt_path for the entry.
-   */
-  olsr_delete_routing_table(&net_to_delete->A_network_addr, net_to_delete->prefixlen, &hna_gw->A_gateway_addr);
-
-  /* Delete hna_gw if empty */
-  if (hna_gw->networks.next == &hna_gw->networks) {
-    DEQUEUE_ELEM(hna_gw);
-    olsr_cookie_free(hna_entry_mem_cookie, hna_gw);
-  }
-
-  DEQUEUE_ELEM(net_to_delete);
-  olsr_cookie_free(hna_net_mem_cookie, net_to_delete);
+  olsr_delete_hna_net_entry(context);
 }
 
 /**
@@ -242,7 +275,7 @@ olsr_expire_hna_net_entry(void *context)
  *@return nada
  */
 void
-olsr_update_hna_entry(const union olsr_ip_addr *gw, const union olsr_ip_addr *net, olsr_u8_t prefixlen, olsr_reltime vtime)
+olsr_update_hna_entry(const union olsr_ip_addr *gw, const union olsr_ip_addr *net, uint8_t prefixlen, olsr_reltime vtime)
 {
   struct hna_entry *gw_entry;
   struct hna_net *net_entry;
@@ -259,19 +292,20 @@ olsr_update_hna_entry(const union olsr_ip_addr *gw, const union olsr_ip_addr *ne
 
     /* Need to add the net */
     net_entry = olsr_add_hna_net(gw_entry, net, prefixlen);
-    changes_hna = OLSR_TRUE;
+    changes_hna = true;
   }
 
   /*
    * Add the rt_path for the entry.
    */
-  olsr_insert_routing_table(&net_entry->A_network_addr, net_entry->prefixlen, &gw_entry->A_gateway_addr, OLSR_RT_ORIGIN_HNA);
+  olsr_insert_routing_table(&net_entry->hna_prefix.prefix,
+      net_entry->hna_prefix.prefix_len, &gw_entry->A_gateway_addr, OLSR_RT_ORIGIN_HNA);
 
   /*
    * Start, or refresh the timer, whatever is appropriate.
    */
   olsr_set_timer(&net_entry->hna_net_timer, vtime, OLSR_HNA_NET_JITTER, OLSR_TIMER_ONESHOT, &olsr_expire_hna_net_entry, net_entry,
-                 hna_net_timer_cookie->ci_id);
+                 hna_net_timer_cookie);
 }
 
 /**
@@ -330,54 +364,45 @@ olsr_print_hna_set(void)
  *@return 1 on success
  */
 
-olsr_bool
+bool
 olsr_input_hna(union olsr_message *m, struct interface *in_if __attribute__ ((unused)), union olsr_ip_addr *from_addr)
 {
 
-  olsr_u8_t olsr_msgtype;
+  uint8_t olsr_msgtype;
   olsr_reltime vtime;
-  olsr_u16_t olsr_msgsize;
+  uint16_t olsr_msgsize;
   union olsr_ip_addr originator;
-  olsr_u8_t hop_count;
-  olsr_u16_t packet_seq_number;
+  uint8_t hop_count;
+  uint16_t msg_seq_number;
 
   int hnasize;
-  const olsr_u8_t *curr, *curr_end;
+  const uint8_t *curr, *curr_end;
 
+  struct ipaddr_str buf;
 #ifdef DEBUG
   OLSR_PRINTF(5, "Processing HNA\n");
 #endif
 
   /* Check if everyting is ok */
   if (!m) {
-    return OLSR_FALSE;
+    return false;
   }
-  curr = (const olsr_u8_t *)m;
+  curr = (const uint8_t *)m;
 
   /* olsr_msgtype */
   pkt_get_u8(&curr, &olsr_msgtype);
   if (olsr_msgtype != HNA_MESSAGE) {
-    OLSR_PRINTF(0, "not a HNA message!\n");
-    return OLSR_FALSE;
+    OLSR_PRINTF(1, "not a HNA message!\n");
+    return false;
   }
   /* Get vtime */
   pkt_get_reltime(&curr, &vtime);
 
   /* olsr_msgsize */
   pkt_get_u16(&curr, &olsr_msgsize);
-  hnasize =
-    olsr_msgsize - (olsr_cnf->ip_version == AF_INET ? offsetof(struct olsrmsg, message) : offsetof(struct olsrmsg6, message));
-  if (hnasize < 0) {
-    OLSR_PRINTF(0, "message size %d too small (at least %lu)!\n", olsr_msgsize,
-                (unsigned long)(olsr_cnf->ip_version ==
-                                AF_INET ? offsetof(struct olsrmsg, message) : offsetof(struct olsrmsg6, message)));
-    return OLSR_FALSE;
-  }
-  if ((hnasize % (2 * olsr_cnf->ipsize)) != 0) {
-    OLSR_PRINTF(0, "Illegal message size %d!\n", olsr_msgsize);
-    return OLSR_FALSE;
-  }
-  curr_end = (const olsr_u8_t *)m + olsr_msgsize;
+
+  hnasize = olsr_msgsize - 8 - olsr_cnf->ipsize;
+  curr_end = (const uint8_t *)m + olsr_msgsize;
 
   /* validate originator */
   pkt_get_ipaddress(&curr, &originator);
@@ -390,7 +415,13 @@ olsr_input_hna(union olsr_message *m, struct interface *in_if __attribute__ ((un
   pkt_get_u8(&curr, &hop_count);
 
   /* seqno */
-  pkt_get_u16(&curr, &packet_seq_number);
+  pkt_get_u16(&curr, &msg_seq_number);
+
+  if ((hnasize % (2 * olsr_cnf->ipsize)) != 0) {
+    OLSR_PRINTF(1, "Illegal HNA message from %s with size %d!\n",
+        olsr_ip_to_string(&buf, &originator), olsr_msgsize);
+    return false;
+  }
 
   /*
    *      If the sender interface (NB: not originator) of this message
@@ -398,34 +429,54 @@ olsr_input_hna(union olsr_message *m, struct interface *in_if __attribute__ ((un
    *      message MUST be discarded.
    */
   if (check_neighbor_link(from_addr) != SYM_LINK) {
-    struct ipaddr_str buf;
     OLSR_PRINTF(2, "Received HNA from NON SYM neighbor %s\n", olsr_ip_to_string(&buf, from_addr));
-    return OLSR_FALSE;
+    return false;
   }
-#if 1
   while (curr < curr_end) {
-    union olsr_ip_addr net;
-    olsr_u8_t prefixlen;
-    struct ip_prefix_list *entry;
+    struct olsr_ip_prefix prefix;
+    union olsr_ip_addr mask;
 
-    pkt_get_ipaddress(&curr, &net);
-    pkt_get_prefixlen(&curr, &prefixlen);
-    entry = ip_prefix_list_find(olsr_cnf->hna_entries, &net, prefixlen);
+    struct ip_prefix_list *entry;
+    struct interface *ifs;
+    bool stop = false;
+
+    pkt_get_ipaddress(&curr, &prefix.prefix);
+    pkt_get_ipaddress(&curr, &mask);
+    prefix.prefix_len = olsr_netmask_to_prefix(&mask);
+
+#ifdef LINUX_NETLINK_ROUTING
+    if (olsr_cnf->smart_gw_active && olsr_is_smart_gateway(&prefix, &mask)) {
+      olsr_update_gateway_entry(&originator, &mask, prefix.prefix_len, msg_seq_number);
+    }
+#endif
+
+#ifdef MAXIMUM_GATEWAY_PREFIX_LENGTH
+    if (olsr_cnf->smart_gw_active && prefix.prefix_len > 0 && prefix.prefix_len <= MAXIMUM_GATEWAY_PREFIX_LENGTH) {
+      continue;
+    }
+#endif
+
+#ifndef NO_DUPLICATE_DETECTION_HANDLER
+    for (ifs = ifnet; ifs != NULL; ifs = ifs->int_next) {
+      if (ipequal(&ifs->ip_addr, &prefix.prefix)) {
+      /* ignore your own main IP as an incoming MID */
+        olsr_handle_hna_collision(&prefix.prefix, &originator);
+        stop = true;
+        break;
+      }
+    }
+    if (stop) {
+      continue;
+    }
+#endif
+    entry = ip_prefix_list_find(olsr_cnf->hna_entries, &prefix.prefix, prefix.prefix_len);
     if (entry == NULL) {
       /* only update if it's not from us */
-      olsr_update_hna_entry(&originator, &net, prefixlen, vtime);
+      olsr_update_hna_entry(&originator, &prefix.prefix, prefix.prefix_len, vtime);
     }
   }
-#else
-  while (hna_tmp) {
-    /* Don't add an HNA entry that we are advertising ourselves. */
-    if (!ip_prefix_list_find(olsr_cnf->hna_entries, &hna_tmp->net, hna_tmp->prefixlen)) {
-      olsr_update_hna_entry(&message.originator, &hna_tmp->net, hna_tmp->prefixlen, message.vtime);
-    }
-  }
-#endif
   /* Forward the message */
-  return OLSR_TRUE;
+  return true;
 }
 
 /*
