@@ -52,7 +52,7 @@ float olsr_hyst_calc_instability(float);
 
 void olsr_update_hysteresis_hello(struct link_entry *, olsr_reltime);
 
-void update_hysteresis_incoming(union olsr_ip_addr *, struct interface *, olsr_u16_t);
+void update_hysteresis_incoming(union olsr_ip_addr *, struct interface *, uint16_t);
 
 #endif
 
