@@ -284,15 +284,9 @@ int olsr_os_policy_rule(int family, int rttable, uint32_t priority, const char *
   req.r.rtm_family = family;
   req.r.rtm_table = rttable;
 
-  /* RTN_UNSPEC would be the wildcard, but blackhole broadcast or nat roules should usually not conflict */
-  /* -> olsr only adds deletes unicast routes */
+  /* probably unneeded */
   req.r.rtm_type = RTN_UNICAST;
 
-  /* wildcard to delete routes of all protos if no simlar-delete correct proto will get set below */
-  req.r.rtm_protocol = RTPROT_UNSPEC;
-
-  req.r.rtm_scope = RT_SCOPE_UNIVERSE;
-
   olsr_netlink_addreq(&req.n, sizeof(req), RTA_PRIORITY, &priority, sizeof(priority));
 
   if (if_name != NULL) {
@@ -369,16 +363,20 @@ static int olsr_new_netlink_route(int family, int rttable, int if_index, int met
 
   memset(&req, 0, sizeof(req));
 
-  req.n.nlmsg_len = NLMSG_LENGTH(sizeof(struct rtmsg));
-  req.n.nlmsg_flags = NLM_F_REQUEST | NLM_F_ACK;
-  if (set) {
-    req.n.nlmsg_flags |= NLM_F_CREATE | NLM_F_REPLACE;
-  }
-
-  req.n.nlmsg_type = set ? RTM_NEWROUTE : RTM_DELROUTE;
+  req.r.rtm_flags = RTNH_F_ONLINK;
   req.r.rtm_family = family;
   req.r.rtm_table = rttable;
 
+  req.n.nlmsg_len = NLMSG_LENGTH(sizeof(struct rtmsg));
+  req.n.nlmsg_flags = NLM_F_REQUEST | NLM_F_ACK;
+
+  if (set) {
+    req.n.nlmsg_flags |= NLM_F_CREATE | NLM_F_REPLACE;
+    req.n.nlmsg_type = RTM_NEWROUTE;
+  } else {
+    req.n.nlmsg_type = RTM_DELROUTE;
+  }
+
   /* RTN_UNSPEC would be the wildcard, but blackhole broadcast or nat roules should usually not conflict */
   /* -> olsr only adds deletes unicast routes */
   req.r.rtm_type = RTN_UNICAST;
@@ -395,13 +393,9 @@ static int olsr_new_netlink_route(int family, int rttable, int if_index, int met
     /* as wildcard for fuzzy deletion */
     req.r.rtm_scope = RT_SCOPE_NOWHERE;
   }
-  else if (gw) {
-    /* for multihop routes */
-    req.r.rtm_scope = RT_SCOPE_UNIVERSE;
-  }
   else {
-    /* for link neighbor routes */
-    req.r.rtm_scope = RT_SCOPE_LINK;
+    /* for all our routes */
+    req.r.rtm_scope = RT_SCOPE_UNIVERSE;
   }
 
   if (set || !del_similar) {
@@ -423,23 +417,33 @@ static int olsr_new_netlink_route(int family, int rttable, int if_index, int met
     /* add gateway */
     olsr_netlink_addreq(&req.n, sizeof(req), RTA_GATEWAY, gw, family_size);
   }
+  else {
+    if ( dst->prefix_len == 32 ) {
+      /* use destination as gateway, to 'force' linux kernel to do proper source address selection */
+      olsr_netlink_addreq(&req.n, sizeof(req), RTA_GATEWAY, &dst->prefix, family_size);
+    }
+    else {
+      /*do not use onlink on such routes(no gateway, but no hostroute aswell) -  e.g. smartgateway default route over an ptp tunnel interface*/
+      req.r.rtm_flags &= (~RTNH_F_ONLINK);
+    }
+  }
 
-  /* add destination */
+   /* add destination */
   olsr_netlink_addreq(&req.n, sizeof(req), RTA_DST, &dst->prefix, family_size);
 
   err = olsr_netlink_send(&req.n);
   if (err) {
-    if (gw) {
       struct ipaddr_str buf;
-      olsr_syslog(OLSR_LOG_ERR, ". error: %s route to %s via %s dev %s (%s %d)",
+    if (gw) {
+      olsr_syslog(OLSR_LOG_ERR, ". error: %s route to %s via %s dev %s onlink (%s %d)",
           set ? "add" : "del",
           olsr_ip_prefix_to_string(dst), olsr_ip_to_string(&buf, gw),
           if_ifwithindex_name(if_index), strerror(errno), errno);
     }
     else {
-      olsr_syslog(OLSR_LOG_ERR, ". error: %s route to %s dev %s (%s %d)",
+      olsr_syslog(OLSR_LOG_ERR, ". error: %s route to %s via %s dev %s onlink (%s %d)",
           set ? "add" : "del",
-          olsr_ip_prefix_to_string(dst), if_ifwithindex_name(if_index),
+          olsr_ip_prefix_to_string(dst), olsr_ip_to_string(&buf, &dst->prefix), if_ifwithindex_name(if_index),
           strerror(errno), errno);
     }
   }
