@@ -38,6 +38,7 @@
  * the copyright holders.
  *
  */
+#include <assert.h>
 
 #include "ipcalc.h"
 #include "defs.h"
@@ -51,6 +52,7 @@
 #include "tc_set.h"
 #include "packet.h"             /* struct mid_alias */
 #include "net_olsr.h"
+#include "duplicate_handler.h"
 
 struct mid_entry mid_set[HASHSIZE];
 struct mid_address reverse_mid_set[HASHSIZE];
@@ -79,6 +81,24 @@ olsr_init_mid_set(void)
   return 1;
 }
 
+void olsr_delete_all_mid_entries(void) {
+  int hash;
+
+  for (hash = 0; hash < HASHSIZE; hash++) {
+    while (mid_set[hash].next != &mid_set[hash]) {
+      olsr_delete_mid_entry(mid_set[hash].next);
+    }
+  }
+}
+
+void olsr_cleanup_mid(union olsr_ip_addr *orig) {
+  struct mid_entry *mid;
+  mid = mid_lookup_entry_bymain(orig);
+  if (mid) {
+    olsr_delete_mid_entry(mid);
+  }
+}
+
 /**
  * Wrapper for the timer callback.
  */
@@ -109,8 +129,12 @@ olsr_expire_mid_entry(void *context)
 static void
 olsr_set_mid_timer(struct mid_entry *mid, olsr_reltime rel_timer)
 {
-
-  olsr_set_timer(&mid->mid_timer, rel_timer, OLSR_MID_JITTER, OLSR_TIMER_ONESHOT, &olsr_expire_mid_entry, mid, 0);
+  int32_t willFireIn = -1;
+  if (mid->mid_timer != NULL) willFireIn = olsr_getTimeDue(mid->mid_timer->timer_clock);
+  
+  if (willFireIn < 0 || (olsr_reltime)willFireIn < rel_timer) {
+    olsr_set_timer(&mid->mid_timer, rel_timer, 0, OLSR_TIMER_ONESHOT, &olsr_expire_mid_entry, mid, 0);
+  }
 }
 
 /**
@@ -120,15 +144,15 @@ olsr_set_mid_timer(struct mid_entry *mid, olsr_reltime rel_timer)
  *
  * @param m_addr the main address of the node
  * @param alias the alias address to insert
- * @return nada
+ * @return false if mid_address is unnecessary, true otherwise
  */
 
-void
+static bool
 insert_mid_tuple(union olsr_ip_addr *m_addr, struct mid_address *alias, olsr_reltime vtime)
 {
   struct mid_entry *tmp;
   struct mid_address *tmp_adr;
-  olsr_u32_t hash, alias_hash;
+  uint32_t hash, alias_hash;
   union olsr_ip_addr *registered_m_addr;
 
   hash = olsr_ip_hashing(m_addr);
@@ -143,9 +167,8 @@ insert_mid_tuple(union olsr_ip_addr *m_addr, struct mid_address *alias, olsr_rel
   /* Check if alias is already registered with m_addr */
   registered_m_addr = mid_lookup_main_addr(&alias->alias);
   if (registered_m_addr != NULL && ipequal(registered_m_addr, m_addr)) {
-
     /* Alias is already registered with main address. Nothing to do here. */
-    return;
+    return false;
   }
 
   /*
@@ -198,7 +221,7 @@ insert_mid_tuple(union olsr_ip_addr *m_addr, struct mid_address *alias, olsr_rel
 
       olsr_delete_two_hop_neighbor_table(tmp_2_neighbor);
 
-      changes_neighborhood = OLSR_TRUE;
+      changes_neighborhood = true;
     }
 
     /* Delete a possible neighbor entry */
@@ -215,10 +238,11 @@ insert_mid_tuple(union olsr_ip_addr *m_addr, struct mid_address *alias, olsr_rel
       /* Delete */
       free(tmp_neigh);
 
-      changes_neighborhood = OLSR_TRUE;
+      changes_neighborhood = true;
     }
     tmp_adr = tmp_adr->next_alias;
   }
+  return true;
 }
 
 /**
@@ -280,13 +304,15 @@ insert_mid_alias(union olsr_ip_addr *main_add, const union olsr_ip_addr *alias,
     }
   }
 
-  insert_mid_tuple(main_add, adr, vtime);
+  if (!insert_mid_tuple(main_add, adr, vtime)) {
+    free(adr);
+  }
 
   /*
    *Recalculate topology
    */
-  changes_neighborhood = OLSR_TRUE;
-  changes_topology = OLSR_TRUE;
+  changes_neighborhood = true;
+  changes_topology = true;
 }
 
 /**
@@ -299,7 +325,7 @@ insert_mid_alias(union olsr_ip_addr *main_add, const union olsr_ip_addr *alias,
 union olsr_ip_addr *
 mid_lookup_main_addr(const union olsr_ip_addr *adr)
 {
-  olsr_u32_t hash;
+  uint32_t hash;
   struct mid_address *tmp_list;
 
   hash = olsr_ip_hashing(adr);
@@ -323,7 +349,7 @@ struct mid_entry *
 mid_lookup_entry_bymain(const union olsr_ip_addr *adr)
 {
   struct mid_entry *tmp_list;
-  olsr_u32_t hash;
+  uint32_t hash;
 
   hash = olsr_ip_hashing(adr);
 
@@ -357,7 +383,7 @@ mid_lookup_aliases(const union olsr_ip_addr *adr)
 int
 olsr_update_mid_table(const union olsr_ip_addr *adr, olsr_reltime vtime)
 {
-  olsr_u32_t hash;
+  uint32_t hash;
   struct ipaddr_str buf;
   struct mid_entry *tmp_list = mid_set;
 
@@ -383,11 +409,13 @@ olsr_update_mid_table(const union olsr_ip_addr *adr, olsr_reltime vtime)
  * @param declared_aliases the list of declared aliases for the MID entry
  * @return nada
  */
-void
-olsr_prune_aliases(const union olsr_ip_addr *m_addr, struct mid_alias *declared_aliases)
+static void
+olsr_prune_aliases(struct mid_message *message)
 {
+  const union olsr_ip_addr *m_addr = &message->mid_origaddr;
+  struct mid_alias * declared_aliases = message->mid_addr;
   struct mid_entry *entry;
-  olsr_u32_t hash;
+  uint32_t hash;
   struct mid_address *registered_aliases;
   struct mid_address *previous_alias;
   struct mid_alias *save_declared_aliases = declared_aliases;
@@ -418,6 +446,12 @@ olsr_prune_aliases(const union olsr_ip_addr *m_addr, struct mid_alias *declared_
       declared_aliases = declared_aliases->next;
     }
 
+    if (declared_aliases == NULL) {
+      /*do not remove alias if vtime still valid (so we assigned something != NULL to declared_aliases)*/
+      if (!olsr_isTimedOut(current_alias->vtime)) declared_aliases = save_declared_aliases;
+    }
+    else current_alias->vtime=olsr_getTimestamp(message->vtime);
+
     if (declared_aliases == NULL) {
       struct ipaddr_str buf;
       /* Current alias not found in list of declared aliases: free current alias */
@@ -444,8 +478,8 @@ olsr_prune_aliases(const union olsr_ip_addr *m_addr, struct mid_alias *declared_
       /*
        *Recalculate topology
        */
-      changes_neighborhood = OLSR_TRUE;
-      changes_topology = OLSR_TRUE;
+      changes_neighborhood = true;
+      changes_topology = true;
     } else {
       previous_alias = current_alias;
     }
@@ -525,12 +559,10 @@ olsr_print_mid_set(void)
  *@return 1 on success
  */
 
-olsr_bool
+bool
 olsr_input_mid(union olsr_message *m, struct interface *in_if __attribute__ ((unused)), union olsr_ip_addr *from_addr)
 {
-#ifdef DEBUG
   struct ipaddr_str buf;
-#endif
   struct mid_alias *tmp_adr;
   struct mid_message message;
 
@@ -538,7 +570,7 @@ olsr_input_mid(union olsr_message *m, struct interface *in_if __attribute__ ((un
 
   if (!olsr_validate_address(&message.mid_origaddr)) {
     olsr_free_mid_packet(&message);
-    return OLSR_FALSE;
+    return false;
   }
 #ifdef DEBUG
   OLSR_PRINTF(5, "Processing MID from %s...\n", olsr_ip_to_string(&buf, &message.mid_origaddr));
@@ -552,30 +584,44 @@ olsr_input_mid(union olsr_message *m, struct interface *in_if __attribute__ ((un
    */
 
   if (check_neighbor_link(from_addr) != SYM_LINK) {
-    struct ipaddr_str buf;
     OLSR_PRINTF(2, "Received MID from NON SYM neighbor %s\n", olsr_ip_to_string(&buf, from_addr));
     olsr_free_mid_packet(&message);
-    return OLSR_FALSE;
+    return false;
   }
 
   /* Update the timeout of the MID */
   olsr_update_mid_table(&message.mid_origaddr, message.vtime);
 
-  while (tmp_adr) {
+  for (;tmp_adr; tmp_adr = tmp_adr->next) {
+#ifndef NO_DUPLICATE_DETECTION_HANDLER
+    struct interface *ifs;
+    bool stop = false;
+    for (ifs = ifnet; ifs != NULL; ifs = ifs->int_next) {
+      if (ipequal(&ifs->ip_addr, &tmp_adr->alias_addr)) {
+      /* ignore your own main IP as an incoming MID */
+        olsr_handle_mid_collision(&tmp_adr->alias_addr, &message.mid_origaddr);
+        stop = true;
+        break;
+      }
+    }
+    if (stop) {
+      continue;
+    }
+#endif
     if (!mid_lookup_main_addr(&tmp_adr->alias_addr)) {
-      struct ipaddr_str buf;
       OLSR_PRINTF(1, "MID new: (%s, ", olsr_ip_to_string(&buf, &message.mid_origaddr));
       OLSR_PRINTF(1, "%s)\n", olsr_ip_to_string(&buf, &tmp_adr->alias_addr));
       insert_mid_alias(&message.mid_origaddr, &tmp_adr->alias_addr, message.vtime);
+    } else {
+      olsr_insert_routing_table(&tmp_adr->alias_addr, olsr_cnf->maxplen, &message.mid_origaddr, OLSR_RT_ORIGIN_MID);
     }
-    tmp_adr = tmp_adr->next;
   }
 
-  olsr_prune_aliases(&message.mid_origaddr, message.mid_addr);
+  olsr_prune_aliases(&message);
   olsr_free_mid_packet(&message);
 
   /* Forward the message */
-  return OLSR_TRUE;
+  return true;
 }
 
 /*
