@@ -45,22 +45,27 @@
 #include "olsr_protocol.h"
 #include "interfaces.h"
 
-extern olsr_bool changes_topology;
-extern olsr_bool changes_neighborhood;
-extern olsr_bool changes_hna;
-extern olsr_bool changes_force;
+extern bool changes_topology;
+extern bool changes_neighborhood;
+extern bool changes_hna;
+extern bool changes_force;
 
 extern union olsr_ip_addr all_zero;
 
+void olsr_startup_sleep(int);
+void olsr_do_startup_sleep(void);
+
 void register_pcf(int (*)(int, int, int));
 
 void olsr_process_changes(void);
 
 void init_msg_seqno(void);
 
-olsr_u16_t get_msg_seqno(void);
+uint16_t get_msg_seqno(void);
 
-int olsr_forward_message(union olsr_message *, union olsr_ip_addr *);
+bool olsr_is_bad_duplicate_msg_seqno(uint16_t seqno);
+
+int olsr_forward_message(union olsr_message *, struct interface *, union olsr_ip_addr *);
 
 void set_buffer_timer(struct interface *);
 
@@ -70,13 +75,13 @@ void olsr_init_willingness(void);
 
 void olsr_update_willingness(void *);
 
-olsr_u8_t olsr_calculate_willingness(void);
+uint8_t olsr_calculate_willingness(void);
 
-const char *olsr_msgtype_to_string(olsr_u8_t);
+const char *olsr_msgtype_to_string(uint8_t);
 
-const char *olsr_link_to_string(olsr_u8_t);
+const char *olsr_link_to_string(uint8_t);
 
-const char *olsr_status_to_string(olsr_u8_t);
+const char *olsr_status_to_string(uint8_t);
 
 void olsr_exit(const char *, int);
 
