@@ -71,7 +71,7 @@
 static int srv_socket;
 
 #define OHS_BUFSIZE 1500
-static olsr_u8_t data_buffer[OHS_BUFSIZE];
+static uint8_t data_buffer[OHS_BUFSIZE];
 
 struct ohs_connection *ohs_conns;
 
@@ -80,7 +80,7 @@ struct ohs_connection *ohs_conns;
 static struct olsrd_config olsr_cnf_data;
 struct olsrd_config *olsr_cnf = &olsr_cnf_data;
 
-olsr_u32_t logbits;
+uint32_t logbits;
 
 /* local functions */
 static int ohs_init_new_connection(int);
@@ -99,10 +99,10 @@ static void ohs_listen_loop(void);
 
 #ifdef WIN32
 int __stdcall
-ohs_close(unsigned long signal __attribute__ ((unused)))
+ohs_close(unsigned long signo __attribute__ ((unused)))
 #else
 void
-ohs_close(int signal __attribute__ ((unused)))
+ohs_close(int signo __attribute__ ((unused)))
 #endif
 {
   printf("OHS: exit\n");
@@ -129,6 +129,7 @@ ohs_init_new_connection(int s)
 {
   struct ohs_connection *oc;
   int i;
+  uint32_t addr[4];
 
   if (logbits & LOG_CONNECT) {
     printf("ohs_init_new_connection\n");
@@ -152,7 +153,7 @@ ohs_init_new_connection(int s)
   /* Get "fake IP" */
   for (i = 0; i < 20; i++) {
     /* Win32 needs that cast. */
-    if (recv(oc->socket, (void *)&oc->ip_addr, olsr_cnf->ipsize, 0) == (int)olsr_cnf->ipsize) {
+    if (recv(oc->socket, (void *)addr, olsr_cnf->ipsize, 0) == (int)olsr_cnf->ipsize) {
       break;
     }
 #if defined WIN32
@@ -165,6 +166,12 @@ ohs_init_new_connection(int s)
     return -1;
   }
 
+  addr[0] = ntohl(addr[0]);
+  addr[1] = ntohl(addr[1]);
+  addr[2] = ntohl(addr[2]);
+  addr[3] = ntohl(addr[3]);
+  memcpy(oc->ip_addr.v6.s6_addr, addr, olsr_cnf->ipsize);
+  
   if (logbits & LOG_CONNECT) {
     struct ipaddr_str addrstr;
     printf("IP: %s\n", olsr_ip_to_string(&addrstr, &oc->ip_addr));
@@ -229,7 +236,7 @@ ohs_route_data(struct ohs_connection *oc)
 
   oc->tx++;
   /* Read data */
-  if ((len = recv(oc->socket, data_buffer, OHS_BUFSIZE, 0)) <= 0)
+  if ((len = recv(oc->socket, (void *)data_buffer, OHS_BUFSIZE, 0)) <= 0)
     return -1;
 
   if (logbits & LOG_FORWARD) {
@@ -253,7 +260,7 @@ ohs_route_data(struct ohs_connection *oc)
                olsr_ip_to_string(&addrstr2, &ohs_cs->ip_addr));
       }
 
-      sent = send(ohs_cs->socket, data_buffer, len, 0);
+      sent = send(ohs_cs->socket, (void*)data_buffer, len, 0);
       if (sent != len) {
         printf("Error sending(buf %d != sent %d)\n", (int)len, (int)sent);
       }
@@ -267,7 +274,7 @@ ohs_route_data(struct ohs_connection *oc)
 static int
 ohs_init_connect_sockets(void)
 {
-  olsr_u32_t yes = 1;
+  uint32_t yes = 1;
   struct sockaddr_in sin;
 
   printf("Initiating socket TCP port %d\n", OHS_TCP_PORT);
@@ -480,7 +487,7 @@ main(void)
     exit(EXIT_FAILURE);
   }
 
-  SetConsoleCtrlHandler(ohs_close, OLSR_TRUE);
+  SetConsoleCtrlHandler(ohs_close, true);
 
 #else
   signal(SIGINT, ohs_close);
