@@ -56,7 +56,9 @@ void olsr_init_export_route(void);
 void olsr_update_rib_routes(void);
 void olsr_update_kernel_routes(void);
 void olsr_delete_all_kernel_routes(void);
-olsr_u8_t olsr_rt_flags(const struct rt_entry *);
+uint8_t olsr_rt_flags(const struct rt_entry *);
+void olsr_delete_interface_routes(int if_index);
+void olsr_force_kernelroutes_refresh(void);
 
 #endif
 
