@@ -60,14 +60,13 @@
 #if defined WINCE
 #define WIDE_STRING(s) L##s
 #else
-#define WIDE_STRING(s) s
+#define WIDE_STRING(s) TEXT(s)
 #endif
 
 void WinSockPError(const char *Str);
 void PError(const char *);
 
 void DisableIcmpRedirects(void);
-int disable_ip_forwarding(int Ver);
 
 int
 gethemusocket(struct sockaddr_in *pin)
@@ -97,7 +96,7 @@ gethemusocket(struct sockaddr_in *pin)
 }
 
 int
-getsocket(int BuffSize, char *Int __attribute__ ((unused)))
+getsocket(int BuffSize, struct interface *ifp __attribute__ ((unused)))
 {
   struct sockaddr_in Addr;
   int On = 1;
@@ -127,13 +126,17 @@ getsocket(int BuffSize, char *Int __attribute__ ((unused)))
     BuffSize -= 1024;
   }
 
-  if (BuffSize <= 8192)
-    fprintf(stderr, "Cannot set IPv4 socket receive buffer.\n");
-
+  if (BuffSize <= 8192) {
+    OLSR_PRINTF(1, "Cannot set IPv4 socket receive buffer.\n");
+  }
   memset(&Addr, 0, sizeof(Addr));
   Addr.sin_family = AF_INET;
-  Addr.sin_port = htons(OLSRPORT);
-  Addr.sin_addr.s_addr = INADDR_ANY;
+  Addr.sin_port = htons(olsr_cnf->olsrport);
+
+  if(BuffSize <= 0) {
+    Addr.sin_addr.s_addr = ifp->int_addr.sin_addr.s_addr;
+  }
+
   if (bind(Sock, (struct sockaddr *)&Addr, sizeof(Addr)) < 0) {
     WinSockPError("getsocket/bind()");
     closesocket(Sock);
@@ -150,7 +153,7 @@ getsocket(int BuffSize, char *Int __attribute__ ((unused)))
 }
 
 int
-getsocket6(int BuffSize, char *Int __attribute__ ((unused)))
+getsocket6(int BuffSize, struct interface *ifp __attribute__ ((unused)))
 {
   struct sockaddr_in6 Addr6;
   int On = 1;
@@ -184,8 +187,12 @@ getsocket6(int BuffSize, char *Int __attribute__ ((unused)))
 
   memset(&Addr6, 0, sizeof(Addr6));
   Addr6.sin6_family = AF_INET6;
-  Addr6.sin6_port = htons(OLSRPORT);
-  //Addr6.sin6_addr.s_addr = IN6ADDR_ANY_INIT;
+  Addr6.sin6_port = htons(olsr_cnf->olsrport);
+
+  if(BuffSize <= 0) {
+    memcpy(&Addr6.sin6_addr, &ifp->int6_addr.sin6_addr, sizeof(struct in6_addr));
+  }
+
   if (bind(Sock, (struct sockaddr *)&Addr6, sizeof(Addr6)) < 0) {
     WinSockPError("getsocket6/bind()");
     closesocket(Sock);
@@ -197,24 +204,21 @@ getsocket6(int BuffSize, char *Int __attribute__ ((unused)))
 
 static OVERLAPPED RouterOver;
 
-int
-enable_ip_forwarding(int Ver)
+void net_os_set_global_ifoptions(void)
 {
   HMODULE Lib;
-  unsigned int __stdcall(*EnableRouter) (HANDLE * Hand, OVERLAPPED * Over);
+  unsigned int __stdcall(*enable_router)(HANDLE *, OVERLAPPED *);
   HANDLE Hand;
 
-  Ver = Ver;
-
   Lib = LoadLibrary(WIDE_STRING("iphlpapi.dll"));
 
   if (Lib == NULL)
-    return 0;
+    return;
 
-  EnableRouter = (unsigned int __stdcall(*)(HANDLE *, OVERLAPPED *))GetProcAddress(Lib, WIDE_STRING("EnableRouter"));
+  enable_router = (unsigned int __stdcall(*)(HANDLE *, OVERLAPPED *))GetProcAddress(Lib, WIDE_STRING("EnableRouter"));
 
-  if (EnableRouter == NULL)
-    return 0;
+  if (enable_router == NULL)
+    return;
 
   memset(&RouterOver, 0, sizeof(OVERLAPPED));
 
@@ -222,24 +226,24 @@ enable_ip_forwarding(int Ver)
 
   if (RouterOver.hEvent == NULL) {
     PError("CreateEvent()");
-    return -1;
+    return;
   }
 
-  if (EnableRouter(&Hand, &RouterOver) != ERROR_IO_PENDING) {
+  if (enable_router(&Hand, &RouterOver) != ERROR_IO_PENDING) {
     PError("EnableRouter()");
-    return -1;
+    return;
   }
 
   OLSR_PRINTF(3, "Routing enabled.\n");
 
-  return 0;
+  return;
 }
 
-int
+static int
 disable_ip_forwarding(int Ver)
 {
   HMODULE Lib;
-  unsigned int __stdcall(*UnenableRouter) (OVERLAPPED * Over, unsigned int *Count);
+  unsigned int __stdcall(*unenable_router)(OVERLAPPED *, unsigned int *);
   unsigned int Count;
 
   Ver = Ver;
@@ -249,12 +253,12 @@ disable_ip_forwarding(int Ver)
   if (Lib == NULL)
     return 0;
 
-  UnenableRouter = (unsigned int __stdcall(*)(OVERLAPPED *, unsigned int *))GetProcAddress(Lib, WIDE_STRING("UnenableRouter"));
+  unenable_router = (unsigned int __stdcall(*)(OVERLAPPED *, unsigned int *))GetProcAddress(Lib, WIDE_STRING("UnenableRouter"));
 
-  if (UnenableRouter == NULL)
+  if (unenable_router == NULL)
     return 0;
 
-  if (UnenableRouter(&RouterOver, &Count) != NO_ERROR) {
+  if (unenable_router(&RouterOver, &Count) != NO_ERROR) {
     PError("UnenableRouter()");
     return -1;
   }
@@ -264,10 +268,11 @@ disable_ip_forwarding(int Ver)
   return 0;
 }
 
+
 int
-restore_settings(int Ver)
+net_os_restore_ifoptions(void)
 {
-  disable_ip_forwarding(Ver);
+  disable_ip_forwarding(olsr_cnf->ip_version);
 
   return 0;
 }
@@ -397,7 +402,19 @@ olsr_recvfrom(int s, void *buf, size_t len, int flags __attribute__ ((unused)),
 int
 olsr_select(int nfds, fd_set * readfds, fd_set * writefds, fd_set * exceptfds, struct timeval *timeout)
 {
+#ifdef WIN32
+  if (nfds == 0) {
+    if (timeout) {
+      Sleep(timeout->tv_sec * 1000 + timeout->tv_usec / 1000);
+    }
+    return 0;
+  }
+  else {
+    return select(nfds, readfds, writefds, exceptfds, timeout);
+  }
+#else
   return select(nfds, readfds, writefds, exceptfds, timeout);
+#endif /*WIN32*/
 }
 
 /*
